<?php
/*
Plugin Name: Booking Package SAASPROJECT
Plugin URI:  https://saasproject.net/plans/
Description: Booking Package is a high-performance booking calencar system that anyone can easily use.
Version:     1.2.46
Author:      SAASPROJECT Booking Package
Author URI:  https://saasproject.net/
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: booking-package
Domain Path: /languages
*/
	
	if(!defined('ABSPATH')){
    	exit;
	}
	
	define("BOOKING_PACKAGE_EXTENSION_URL", "https://saasproject.net/api/1.2/");
	
	define("BOOKING_PACKAGE_STRIPE_PUBLIC_KEY", "pk_live_6o6UUlTOZInuOGEQPPjkfuyU");
	
	class Booking_app {
		
		public $db_version = "0.1.2";
		
		public $plugin_version = 0;
		
		public $table_name = null;
		
		public $plugin_name = "booking-package";
		
		public $prefix = 'booking_package_';
		
		public $action_control = "booking_app_action";
		
		public $action_public = "booking_app_public_action";
		
		public $locale = "en";
		
		public $is_mobile = 0;
		
		public $calendarAccountType = 1;
		
		public $webApp = 0;
		
		public function __construct() {
			
			#ini_set('display_errors', 1);
			
			global $wpdb;
			if(wp_is_mobile() === true){
				
				$this->is_mobile = 1;
				
			}
			
			if(function_exists('register_activation_hook')){
				
				register_activation_hook(__FILE__, array($this,'create_database'));
				
			}
			
			if(function_exists('register_deactivation_hook')){
				
				#register_deactivation_hook(__FILE__, array($this,'deactivation'));
				register_deactivation_hook(__FILE__, array($this, 'deactivation_event'));
				
			}
			
			if(isset($_GET['key']) && isset($_GET['calendar']) && isset($_GET['month']) && isset($_GET['day']) && isset($_GET['year'])){
				
				$expire = date('U') + (30 * 24 * 3600);
				setcookie($this->prefix.'accountKey', intval($_GET['calendar']), $expire);
				
			}
			
			$plugin_headers = get_file_data(__FILE__, array('version' => 'Version', 'Page Name' => 'Page Name'));
			$this->plugin_version = $plugin_headers['version'];
			
			add_filter( 'locale', array($this, 'plugin_localized'));
			
			$pluginName = $this->plugin_name;
			$test = load_plugin_textdomain($pluginName, false, dirname( plugin_basename( __FILE__ ) ).'/languages');
			
			add_action('wp_dashboard_setup', array($this, 'add_dashboard_widget'));
			add_action('admin_menu', array($this, 'add_pages'));
			add_action('admin_bar_menu', array($this, 'admin_bar_menu'), 100);
			add_action('wp_ajax_'.$this->action_control, array($this, 'wp_ajax_booking_package'));
			add_action('wp_ajax_nopriv_'.$this->action_control, array($this, 'wp_ajax_booking_package'));
			add_action('wp_ajax_'.$this->action_public, array($this, 'wp_ajax_booking_package_for_public'));
			add_action('wp_ajax_nopriv_'.$this->action_public, array($this, 'wp_ajax_booking_package_for_public'));
			
			add_shortcode('booking_app', array($this, 'bookingPageForVisitors'));
			add_shortcode('booking_package', array($this, 'bookingPageForVisitors'));
			
			
			add_filter('cron_schedules', array($this, 'cron_interval'));
			add_action('retry_to_send_to_server', array($this, 'retry_to_send_to_server'));
			if(!wp_next_scheduled('retry_to_send_to_server')){
				
				wp_schedule_event(time(), 'retry_to_send_to_server_thirty_minutes', 'retry_to_send_to_server');
				
			}
			
			add_action('admin_head', array($this, 'screen_meta'));
			
			
			if(isset($_GET['ical'])){
				
				add_action('init', array($this, 'ical_feeds'));
				
			}
			
			if(isset($_GET['webhook']) || isset($_POST['webhook'])){
				
				add_action('init', array($this, 'webhook'));
				
			}
			
			if(isset($_POST['api'])){
				
				add_action('init', array($this, 'api'));
				
			}
			
			if(isset($_POST['app']) || isset($_GET['app'])){
				
				add_action('init', array($this, 'app'));
				
			}
			
		}
		
		public function plugin_localized($locale){
			
			if(isset($_POST['locale'])){
				
				$this->locale = sanitize_text_field($_POST['locale']);
				return sanitize_text_field($_POST['locale']);
				
			}
			
			if(isset($_GET['locale'])){
				
				$this->locale = sanitize_text_field($_GET['locale']);
				return sanitize_text_field($_GET['locale']);
				
			}
			
			$this->locale = $locale;
			return $locale;
			
		}
		
		public function create_database($update = false){
			
			require_once(get_home_path() . 'wp-admin/includes/upgrade.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Database.php');
			
			if($update == false){
				
				add_option($this->prefix."javascriptSyntaxErrorNotification", 1);
				
			}
			
			$database = new Database($this->prefix, $this->db_version);
			$database->create();
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$setting->activation(BOOKING_PACKAGE_EXTENSION_URL, "activation");
			
			$this->createFirstCalendar();
			
		}
		
		public function update_database(){
			
			$installed_ver = get_option($this->prefix."db_version");
			if($installed_ver != $this->db_version){
				$this->create_database(true);
				update_option($this->prefix."db_version", $this->db_version);
				
			}
			
		}
		
		public function admin_bar_menu($wp_admin_bar){
			
			wp_enqueue_style( 'Control.css', plugin_dir_url( __FILE__ ).'css/Control.css', array(), $this->plugin_version);
			$title = '<span class="top_toolbar_icon"></span><span>'.__("Booking Package", $this->plugin_name).'</span>';
			$plugin_top_bar = $this->plugin_name.'_top_bar';
			$args = array(
							"id" => $plugin_top_bar,
							"meta" => array(), 
							'title' => $title,
							'href' => admin_url("admin.php?page=".$this->plugin_name."/index.php")
						);
						
			$wp_admin_bar->add_node($args);
			$args = array(
							"id" => $plugin_top_bar."_report",
							"parent" => $plugin_top_bar, 
							"meta" => array(), 
							'title' => __('Report & Booking', $this->plugin_name),
							'href' => admin_url("admin.php?page=".$this->plugin_name."/index.php")
						);
						
			$wp_admin_bar->add_node($args);
			
			$args = array(
							"id" => $plugin_top_bar."_schedule",
							"parent" => $plugin_top_bar, 
							"meta" => array(), 
							'title' => __('Calendar Setting', $this->plugin_name),
							'href' => admin_url("admin.php?page=".$this->plugin_name."_schedule_page")
						);
			$wp_admin_bar->add_node($args);
			
			$args = array(
							"id" => $plugin_top_bar."_setting",
							"parent" => $plugin_top_bar, 
							"meta" => array(), 
							'title' => __('General Setting', $this->plugin_name),
							'href' => admin_url("admin.php?page=".$this->plugin_name."_setting_page")
						);
			$wp_admin_bar->add_node($args);
				
			
		}
		
		public function add_pages() {
			
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$calendarAccountList = $schedule->getCalendarAccountListData("`key`,`googleCalendarID`,`idForGoogleWebhook`,`expirationForGoogleWebhook`");
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$response = $setting->updateChannelGC($calendarAccountList);
			if(!is_null($response) && !isset($response['status'])){
				
				for($i = 0; $i < count($response); $i++){
					
					$webhookDetails = $response[$i];
					$schedule->updateCalendarAccountForGoogleWebhook($webhookDetails['key'], $webhookDetails['id'], $webhookDetails['expiration']);
					
				}
				
			}
			
			$plugin_name = $this->plugin_name.'_admin';
			/**
			add_menu_page($plugin_name, __('Booking Package', $this->plugin_name), 'level_8', $this->plugin_name.'_report_and_booking', array($this,'adomin'), 'dashicons-calendar-alt', 26);
			add_submenu_page(__FILE__, $plugin_name, __('Report & Booking', $this->plugin_name),  'level_8', $this->plugin_name.'_report_and_booking', array($this,'adomin'));
			add_submenu_page(__FILE__, $plugin_name, __('Schedule', $this->plugin_name),  'edit_themes', $this->plugin_name.'_schedule_page', array($this,'schedule_page'));
			add_submenu_page(__FILE__, $plugin_name, __('General Setting', $this->plugin_name),  'edit_themes', $this->plugin_name.'_setting_page', array($this,'setting_page'));
			**/
			add_menu_page($plugin_name, __('Booking Package', $this->plugin_name), 'manage_categories', __FILE__, array($this,'adomin'), 'dashicons-calendar-alt', 26);
			add_submenu_page(__FILE__, $plugin_name, __('Report & Booking', $this->plugin_name),  'manage_categories', __FILE__, array($this,'adomin'));
			add_submenu_page(__FILE__, $plugin_name, __('Calendar Setting', $this->plugin_name),  'manage_categories', $this->plugin_name.'_schedule_page', array($this,'schedule_page'));
			add_submenu_page(__FILE__, $plugin_name, __('General Setting', $this->plugin_name),  'manage_categories', $this->plugin_name.'_setting_page', array($this,'setting_page'));
		}
		
		public function add_dashboard_widget(){
			
			wp_add_dashboard_widget($this->plugin_name, 'Booking Package', array($this, 'dashboard_widget_function'));
			
			global $wp_meta_boxes;
			$normal_dashboard = $wp_meta_boxes['dashboard']['normal']['core'];
			$example_widget_backup = array($this->plugin_name => $normal_dashboard[$this->plugin_name]);
			unset($normal_dashboard[$this->plugin_name]);
			$sorted_dashboard = array_merge($example_widget_backup, $normal_dashboard);
			$wp_meta_boxes['dashboard']['normal']['core'] = $sorted_dashboard;
			
		}
		
		public function dashboard_widget_function(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$calendarAccountList = $schedule->getCalendarAccountListData("`key`,`name`,`type`,`status`");
			$newCalendarAccountList = array();
			for($i = 0; $i < count($calendarAccountList); $i++){
				
				$newCalendarAccountList[$calendarAccountList[$i]['key']] = $calendarAccountList[$i];
				
			}
			
			$calendarAccountList = $newCalendarAccountList;
			$setting = new setting($this->prefix, $this->plugin_name);
			$emailMessageList = $setting->getEmailMessage(array('enable'));
			
			$dictionary = $this->getDictionary("adomin", $this->plugin_name);
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_control, 
				'nonce' => wp_create_nonce($this->action_control."_ajax"), 
				'prefix' => $this->prefix,
				'courseBool' => $courseBool, 
				'courseName' => $courseName, 
				'year' => date('Y'), 
				'month' => date('m'), 
				'day' => date('d'), 
				'locale' => get_locale(),
				'courseList' => $courseList, 
				'currency' => $list['General']['booking_package_currency']['value'],
				'dateFormat' => $dateFormat,
				'positionOfWeek' => $positionOfWeek,
				'emailEnable' => $emailMessageList,
				'bookingBool' => 0,
				'calendarAccountList' => $calendarAccountList,
				'error_url' => BOOKING_PACKAGE_EXTENSION_URL,
			);
			
			$p_v = "?p_v=".$this->plugin_version;
			wp_enqueue_style( 'Control.css', plugin_dir_url( __FILE__ ).'css/Control.css', array(), $this->plugin_version);
			wp_enqueue_style( 'Control_for_madia_css', plugin_dir_url( __FILE__ ).'css/Control_for_madia.css', array(), $this->plugin_version);
			wp_enqueue_script( 'Error_js', plugin_dir_url( __FILE__ ).'js/Error.js'.$p_v);
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js'.$p_v);
			wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js'.$p_v);
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js'.$p_v);
			wp_enqueue_script( 'Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js'.$p_v);
			wp_enqueue_script( 'Reservation_manage_js', plugin_dir_url( __FILE__ ).'js/Reservation_manage.js'.$p_v);
			wp_localize_script('Reservation_manage_js', 'schedule_data', $localize_script);
			wp_localize_script('Reservation_manage_js', $this->prefix.'dictionary', $dictionary);
			
			print "<div id='booking_pacage_dashboard_widget'>";
			
			$dateFormat = intval(get_option($this->prefix."dateFormat", 0));
			$unixTime = date('U');
			$today = $schedule->dateFormat($dateFormat, date('w'), $unixTime, null, null);
			$lists = $schedule->getReservationUsersData(date('n', $unixTime), date('j', $unixTime), date('Y', $unixTime));
			$this->visitorsList($today, $unixTime, $calendarAccountList, $lists, $schedule);
			
			$unixTime += 1440 * 60;
			$nextDay = $schedule->dateFormat($dateFormat, date('w', $unixTime), $unixTime, null, null);
			$lists = $schedule->getReservationUsersData(date('n', $unixTime), date('j', $unixTime), date('Y', $unixTime));
			$this->visitorsList($nextDay, $unixTime, $calendarAccountList, $lists, $schedule);
			
			print "</div>";
			
			?>
			<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
			<div id="dialogPanel" class="hidden_panel">
				<div class="blockPanel"></div>
				<div class="confirmPanel">
					<div class="subject"><?php _e("Title", $pluginName); ?></div>
					<div class="body"><?php _e("Message", $pluginName); ?></div>
					<div class="buttonPanel">
						<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
						<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
					</div>
				</div>
			</div>
			<!--
			<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
			-->
			<div id="loadingPanel" class="hidden_panel">
				<div class="loader">
					<svg viewBox="0 0 64 64" width="64" height="64">
						<circle id="spinner" cx="32" cy="32" r="28" fill="none"></circle>
					</svg>
				</div>
			</div>
			<?php
			
		}
		
		public function visitorsList($date, $unixTime, $calendarAccountList, $lists, $schedule){
			
			$dateFormat = get_option($this->prefix."dateFormat", "0");
			$url = admin_url("admin.php?page=".$this->plugin_name."/index.php");
			print "<div class='title'>".$date."</div>";
			$i = 0;
			foreach($lists as $key => $value){
				
				if(isset($calendarAccountList[$key])){
					
					$i++;
					print "<div class='calendarName'>".$calendarAccountList[$key]['name']."</div>";
					print "<ul class=''>";
					for($i = 0; $i < count($value); $i++){
						
						$this->showVisitorsList($value[$i], $url, $calendarAccountList[$key]['type'], $schedule, $dateFormat);
						
					}
					
					print "</ul>";
					
				}
				
			}
			
			if($i == 0){
				
				print "<div class='calendarName'>".__('No visitors', $this->plugin_name)."</div>";
				
			}
			
		}
		
		public function showVisitorsList($visitor, $url, $calendarType, $schedule, $dateFormat){
			
			$date = null;
			$visitor['date'] = array('month' => date('n', $visitor['scheduleUnixTime']), 'year' => date('Y', $visitor['scheduleUnixTime']));
			if($calendarType == 'day'){
				
				$date = date('H:i', $visitor['scheduleUnixTime']).' '.$visitor['courseName'];
				
			}else if($calendarType == 'hotel'){
				
				$checkIn = $visitor['accommodationDetails']['checkIn'];
				$checkOut = $visitor['accommodationDetails']['checkOut'];
				#$date = $schedule->dateFormat($dateFormat, date('w', $checkIn), $checkIn, null, false, true)." - ";
				#$date .= $schedule->dateFormat($dateFormat, date('w', $checkOut), $checkOut, null, false, true);
				$date = sprintf(__('Until %s', $this->plugin_name), $schedule->dateFormat($dateFormat, date('w', $checkOut), $checkOut, null, false, true));
			}
			
			$url .= "&key=".intval($visitor['key'])."&calendar=".intval($visitor['accountKey'])."&month=".intval(date('n', $visitor['scheduleUnixTime']))."&day=".intval(date('j', $visitor['scheduleUnixTime']))."&year=".intval(date('Y', $visitor['scheduleUnixTime']));
			$praivateData = $visitor['praivateData'];
			$name = array();
			for($i = 0; $i < count($praivateData); $i++){
				
				if($praivateData[$i]['isName'] == 'true'){
					
					array_push($name, $praivateData[$i]['value']);
					
				}
				
			}
			
			$name = strtoupper(implode(' ', $name));
			?>
			
			<li class=''>
				<div class='date'><?php print $date; ?></div>
				<div onClick='changeStatusForDashboard(this, <?php print json_encode($visitor); ?>)' class='status <?php print $visitor['status']; ?>'><?php print __(strtoupper($visitor['status']), $this->plugin_name); ?></div>
				<div class='name'><a href='<?php print $url; ?>'><?php print $name; ?></a></div>
			</li>
			
			<?php
			
		}
		
		public function bookingPageForVisitors($atts){
			
			$atts = extract(shortcode_atts(array('id' => 1), $atts));
			#var_dump($atts);
			$accountKey = $id;
			#var_dump($accountKey);
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
            
            $p_v = "?p_v=".$this->plugin_version;
            wp_enqueue_style( 'booking_app_js_css', plugin_dir_url( __FILE__ ).'css/Booking_app.css'.$p_v);
			wp_enqueue_style('https://fonts.googleapis.com/icon?family=Material+Icons');
            
            $this->update_database();
            require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
            require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
            $setting = new setting($this->prefix, $this->plugin_name);
			$list = $setting->getList();
			
			$courseList = $setting->getCourseList($accountKey);
			$formData = $setting->getForm($accountKey);
			
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$schedule->deleteOldDaysInSchedules();
			$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
			$calendarAccount = $schedule->getCalendarAccount($accountKey);
			unset($calendarAccount['googleCalendarID']);
			unset($calendarAccount['idForGoogleWebhook']);
			unset($calendarAccount['expirationForGoogleWebhook']);
			
			$guestsList = $setting->getGuestsList($accountKey, true);
			
			if($calendarAccount['status'] == 'close'){
				
				return '<div id="calendarStatus">'.__('We do not accept reservations for this calendar.', $this->plugin_name).'</div>';
				
			}
			
			$dateFormat = get_option($this->prefix."dateFormat", "0");
			$positionOfWeek = get_option($this->prefix."positionOfWeek", "before");
			$courseBool = "false";
			if(intval($calendarAccount["courseBool"]) == 1){
				
				$courseBool = "true";
				
			}
			
			$locale = get_locale();
			$dictionary = $this->getDictionary("bookingPageForVisitors", $this->plugin_name);
			
			/**
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				#'url' => plugin_dir_url( __FILE__ ).'ajax.php',
				'action' => $this->action_public, 
				'nonce' => wp_create_nonce($this->action_public."_ajax"), 
				'courseBool' => $courseBool, 
				'courseName' => $calendarAccount["courseTitle"], 
				'year' => date('Y'), 
				'month' => date('m'), 
				'day' => date('d'), 
				'courseList' => $courseList, 
				'country' => $list['General']['booking_package_country']['value'],
				'currency' => $list['General']['booking_package_currency']['value'],
				'dateFormat' => $dateFormat,
				'positionOfWeek' => $positionOfWeek,
				'formData' => $formData,
				'locale' => $locale,
				'accountKey' => $accountKey,
				'calendarAccount' => $calendarAccount,
				'guestsList' => $guestsList,
				'is_mobile' => $this->is_mobile,
				'javascriptSyntaxErrorNotification' => $javascriptSyntaxErrorNotification,
				'javascriptFileslist' => $javascriptFileslist,
			);
			**/
			
			$localize_script = $this->localizeScript("visitor");
			$localize_script['courseBool'] = $courseBool;
			$localize_script['courseName'] = $calendarAccount["courseTitle"];
			$localize_script['accountKey'] = $accountKey;
			$localize_script['calendarAccount'] = $calendarAccount;
			$localize_script['courseList'] = $courseList;
			$localize_script['guestsList'] = $guestsList;
			$localize_script['formData'] = $formData;
			$localize_script['enableFixCalendar'] = intval($calendarAccount['enableFixCalendar']);
			if(intval($calendarAccount['enableFixCalendar']) == 1){
				
				$localize_script['month'] = intval($calendarAccount['monthForFixCalendar']) + 1;
				$localize_script['year'] = intval($calendarAccount['yearForFixCalendar']);
				
			}
			
			if(intval(get_option($this->prefix."stripe_active", 0)) == 1){
				
				$stripe_public_key = get_option($this->prefix."stripe_public_key", null);
				if(!is_null($stripe_public_key)){
					
					$localize_script['stripe_active'] = 1;
					$localize_script['stripe_public_key'] = $stripe_public_key;
					wp_enqueue_script('stripe_checkout_v3_js', 'https://js.stripe.com/v3/');
					
				}else{
					
					$localize_script['stripe_active'] = 0;
					
				}
				
			}else{
				
				$localize_script['stripe_active'] = 0;
				
			}
			
			wp_enqueue_script( 'Error_js', plugin_dir_url( __FILE__ ).'js/Error.js'.$p_v);
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js'.$p_v);
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js'.$p_v);
			wp_enqueue_script( 'Input_js', plugin_dir_url( __FILE__ ).'js/Input.js'.$p_v);
			wp_enqueue_script( 'Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js'.$p_v);
			wp_enqueue_script('booking_app_js', plugin_dir_url( __FILE__ ).'js/Booking_app.js'.$p_v);
			wp_enqueue_script('Hotel_js', plugin_dir_url( __FILE__ ).'js/Hotel.js'.$p_v);
			wp_localize_script('booking_app_js', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('booking_app_js', 'reservation_info', $localize_script);
			
			
			$html = '<div id="bookingPackage">';
			#$html .= '<div id="bookingBlockPanel" class="hidden_panel"><img src="'.plugin_dir_url( __FILE__ ).'images/loading_0.gif"></img></div>';
			$html .= '	<div id="calendarPage"></div>';
			$html .= '	<div id="durationStay"></div>';
			$html .= '	<div id="schedulePage" class="hidden_panel"></div>';
			$html .= '	<div id="inputFormPanel" class="hidden_panel"></div>';
			$html .= '	<div id="bookingBlockPanel" class="hidden_panel">';
			$html .= '		<div id="bookingBlockPanel" class="">';
			$html .= '			<div class="loader" class="hidden_panel">';
			$html .= '				<svg viewBox="0 0 64 64" width="64" height="64">';
			$html .= '					<circle id="spinner" cx="32" cy="32" r="28" fill="none"></circle>';
			$html .= '				</svg>';
			$html .= '			</div>';
			$html .= '		</div>';
			$html .= '	</div>';
			$html .= '</div>';
			
			$style = $this->getStyle($list);
			$html .= $style;
			
			return $html;
			
		}
		
		public function adomin() {
			
			$this->update_database();
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Webhook.php');
            require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$setting = new setting($this->prefix, $this->plugin_name);
			if(isset($_GET['mode']) && $_GET['mode'] == 'upgradePlan'){
				
				$response = $setting->upgradePlan($_GET['type']);
				$response = $setting->extensionFunction(false);
				
			}
			
			$timeMin = date('U') - (7 * 24 * 60 * 60);
            
            $webhook = new Webhook($this->prefix, $this->plugin_name);
            #$webhook->catchWebhook("", "", "", "");
            
            $schedule = new Schedule($this->prefix, $this->plugin_name);
            $schedule->deleteOldDaysInSchedules();
            $schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
            #$schedule->retryToSendToServer();
            
            
			/**
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_control, 
				'nonce' => wp_create_nonce($this->action_control."_ajax"), 
				'prefix' => $this->prefix,
				'courseBool' => $courseBool, 
				'courseName' => $courseName, 
				'year' => date('Y'), 
				'month' => date('m'), 
				'day' => date('d'), 
				'locale' => $locale,
				'courseList' => $courseList, 
				'country' => $list['General']['booking_package_country']['value'],
				'currency' => $list['General']['booking_package_currency']['value'],
				'dateFormat' => $dateFormat,
				'positionOfWeek' => $positionOfWeek,
				'formData' => $formData,
				'calendarAccountList' => $schedule->getCalendarAccountListData(),
				'is_mobile' => $this->is_mobile,
				'dashboardRequest' => $dashboardRequest,
				'bookingBool' => 1,
			);
			$localize_script['emailEnable'] = $emailMessageList;
            **/
            
            $dictionary = $this->getDictionary("adomin", $this->plugin_name);
            $localize_script = $this->localizeScript('adomin');
            
            $p_v = "?p_v=".$this->plugin_version;
			wp_enqueue_style( 'Control.css', plugin_dir_url( __FILE__ ).'css/Control.css', array(), $this->plugin_version);
			wp_enqueue_style( 'Control_for_madia_css', plugin_dir_url( __FILE__ ).'css/Control_for_madia.css', array(), $this->plugin_version);
			$fontFaceStyle = $this->getFontFaceStyle();
            wp_add_inline_style("Control.css", $fontFaceStyle);
            wp_enqueue_script( 'Error_js', plugin_dir_url( __FILE__ ).'js/Error.js'.$p_v);
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js'.$p_v);
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js'.$p_v);
			wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js'.$p_v);
			wp_enqueue_script( 'Input_js', plugin_dir_url( __FILE__ ).'js/Input.js'.$p_v);
			wp_enqueue_script( 'Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js'.$p_v);
			wp_enqueue_script( 'Hotel_js', plugin_dir_url( __FILE__ ).'js/Hotel.js'.$p_v);
			wp_enqueue_script( 'Reservation_manage_js', plugin_dir_url( __FILE__ ).'js/Reservation_manage.js'.$p_v);
			
			wp_localize_script('Reservation_manage_js', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('Reservation_manage_js', 'schedule_data', $localize_script);
			wp_enqueue_script( 'Reservation_manage_js' );
			
			
			$isExtensionsValid = $setting->extensionFunction();
			
			$updated_style = "display: none;";
			$control_panel_button_style = "display: none;";
			$user = wp_get_current_user();
			if(!empty($_POST) && $user->allcaps['manage_options'] === true){
				
				if(check_admin_referer('booking_package_action', 'booking_package_nonce_field')){
					
					
					
				}
				
			}
			
			$active = get_option("booking_package_active", 0);
			$booking_package_id = get_option("booking_package_id", "");
			$booking_package_path = get_option("booking_package_path", "");
			$booking_package_script_path = get_option("booking_package_script_path", "");
			$booking_package_serial = get_option("booking_package_serial", "");
			
			if(!empty($booking_package_script_path)){
				
				$control_panel_button_style = "";
				
			}
			
			$pluginName = $this->plugin_name;
			
			?>
			<div class="wrap">
				<div class="top_bar">
					<!--
					<h1 class="wp-heading-inline top_title_h1"><?php _e("Report & Booking", $pluginName); ?></h1>
					-->
					<?php
						
					$this->upgradeButton($isExtensionsValid);
						
					?>
				</div>
				<div class="<?php print $update_class; ?> settings-error notice is-dismissible" id="res" style="<?php print $updated_style; ?>"><?php print $update_value; ?></div>
				
				<div id="select_package" class="welcome-panel">
					<div id="calendarPage"></div>
				</div>
				
				<div id="editPanel" class="edit_modal hidden_panel">
					<button type="button" id="media_modal_close" class="media_modal_close">
						<span class="">
							<span class="material-icons">close</span>
						</span>
					</button>
					<div class="edit_modal_content">
						<div id="menu_panel" class="media_frame_menu">
							<div id="media_menu" class="media_menu"></div>
						</div>
						<div id="media_title" class="media_frame_title"><h1 id="edit_title"></h1></div>
						<div id="media_router" class="media_frame_router">
							<div class="reservation_table_row">
								<div id="reservation_users" class="media_menu_item active"><?php _e("List of visitors", $pluginName); ?></div>
								<div id="add_reservation" class="media_menu_item"><?php _e("Booking now", $pluginName); ?></div>
							</div>
						</div>
						<div id="media_frame_reservation_content"></div>
						<div id="frame_toolbar" class="media_frame_toolbar">
							<div class="media_toolbar">
								<div id="buttonPanel" class="media_toolbar_primary" style="float: initial;">
									
									<div id="leftButtonPanel"></div>
									<div id="rightButtonPanel"></div>
									
								</div>
							</div>
						</div>
						
					</div>
					
				</div>
				
				<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
				
				<div id="dialogPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					<div class="confirmPanel">
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div class="body"><?php _e("Message", $pluginName); ?></div>
						<div class="buttonPanel">
							<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
							<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
						</div>
					</div>
				</div>
				
			<!-- /.wrap -->
			</div>	
			<!--
			<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
			-->
			<div id="loadingPanel">
				<div class="loader">
					<svg viewBox="0 0 64 64" width="64" height="64">
						<circle id="spinner" cx="32" cy="32" r="28" fill="none"></circle>
					</svg>
				</div>
			</div>
			
			
			<?php
			
			#print '<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="'.plugin_dir_url( __FILE__ ).'images/loading_0.gif"></div>';
			
		}
		
		public function schedule_page(){
			
			$this->update_database();
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
			
			$setting = new setting($this->prefix, $this->plugin_name);
			
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$schedule->deleteOldDaysInSchedules();
			$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
			
			/**
			$dateFormat = get_option($this->prefix."dateFormat", "0");
			$courseBool = get_option($this->prefix."courseBool", "false");
			$positionOfWeek = get_option($this->prefix."positionOfWeek", "before");
			$locale = get_locale();
			$elementForCalendarAccount = $setting->getElementForCalendarAccount();
			
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_control, 
				'nonce' => wp_create_nonce($this->action_control."_ajax"), 
				'courseBool' => $courseBool, 
				'year' => date('Y'), 
				'month' => date('m'), 
				'locale' => $locale, 
				'dateFormat' => $dateFormat, 
				'positionOfWeek' => $positionOfWeek,
				'list' => $list, 
				'formInputType' => $formInputType, 
				'courseData' => $courseData,
				'elementForCalendarAccount' => $elementForCalendarAccount, 
				'guestsInputType' => $setting->guestsInputType(),
				'is_mobile' => $this->is_mobile,
			);
			**/
			
			
			$dictionary = $this->getDictionary("schedule_page", $this->plugin_name);
			$localize_script = $this->localizeScript('schedule_page');
			$isExtensionsValid = $setting->extensionFunction(true);
			if($isExtensionsValid == true){
				
				$localize_script['isExtensionsValid'] = 1;
				
			}else{
				
				$localize_script['isExtensionsValid'] = 0;
				
			}
			
			$p_v = "?p_v=".$this->plugin_version;
			wp_print_scripts(array( 'jquery-ui-sortable'.$p_v));
			wp_enqueue_style('Control.css', plugin_dir_url( __FILE__ ).'css/Control.css', array(), $this->plugin_version);
			wp_enqueue_style('Control_for_madia_css', plugin_dir_url( __FILE__ ).'css/Control_for_madia.css', array(), $this->plugin_version);
			$fontFaceStyle = $this->getFontFaceStyle();
            wp_add_inline_style("Control.css", $fontFaceStyle);
            wp_enqueue_script('Error_js', plugin_dir_url( __FILE__ ).'js/Error.js'.$p_v);
			wp_enqueue_script('i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js'.$p_v);
			wp_enqueue_script('XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js'.$p_v);
			wp_enqueue_script('Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js'.$p_v);
			wp_enqueue_script('Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js'.$p_v);
			wp_enqueue_script('input_js', plugin_dir_url( __FILE__ ).'js/Input.js'.$p_v);
			wp_enqueue_script('schedule_pange', plugin_dir_url( __FILE__ ).'js/Schedule.js'.$p_v, array('jquery'));
			wp_localize_script('schedule_pange', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('schedule_pange', 'schedule_data', $localize_script);
			
			
			
			$pluginName = $this->plugin_name;
			
			?>
				
				<div id="select_package" class="wrap">
					
					<div class="top_bar">
						<!--
						<h1 class="wp-heading-inline top_title_h1"><?php _e("Schedule setting", $pluginName); ?></h1>
						-->
						
					</div>
					<!-- <div id="select_package" class="welcome-panel"><div>  -->
					<!-- <div id="select_package"></div> -->
					
					
							<div id="calendarAccountList">
								<div class="actionButtonPanel">
									<button id="add_new_calendar" type="button" class="w3tc-button-save button-primary" style="margin-right: 10px;"><?php _e("Add new calendar", $pluginName); ?></button>
									<?php
									
										$this->upgradeButton($isExtensionsValid);
									
									?>
								</div>
								<table id="calendar_list_table" class="wp-list-table widefat fixed striped"></table>
								
							</div>
							<div id="tabFrame" class="hidden_panel">
								<div class="actionButtonPanel">
									<button id="return_to_calendar_list" type="button" class="w3tc-button-save button-primary" style="margin-right: 10px;"><?php _e("Return to Calendar list", $pluginName); ?></button>
									
								</div>
								
								<div style="overflow-x: auto;">
									<div class="menuList">
										<div id="calendarLink" class="menuItem active"><?php _e("Schedule", $pluginName); ?></div>
										<div id="formLink" class="menuItem hidden_panel"><?php _e("Form fields", $pluginName); ?></div>
										<div id="courseLink" class="menuItem hidden_panel"><?php _e("Services", $pluginName); ?></div>
										<div id="guestsLink" class="menuItem hidden_panel"><?php _e("Guests", $pluginName); ?></div>
										<div id="emailLink" class="menuItem hidden_panel"><?php _e("Emails message", $pluginName); ?></div>
										<div id="settingLink" class="menuItem hidden_panel"><?php _e("Setting", $pluginName); ?></div>
									</div>
								</div>
								<div id="contentPanel" class="content">
									<div id="schedulePage"></div>
									<div id="formPanel" class="hidden_panel"></div>
									<div id="coursePanel" class="hidden_panel"></div>
									<div id="guestsPanel" class="hidden_panel"></div>
									<div id="emailPanel" class="hidden_panel">
										<div id="mailSettingPanel">
											<div id="mailSettingButtonPanel"></div>
											<div id="content_area"></div>
										</div>
									</div>
									<div id="settingPanel" class="hidden_panel"></div>
								</div>
							
							</div>
						
					
				</div>
				
				<div id="editPanelForSchedule" class="edit_modal hidden_panel">
					<button type="button" id="media_modal_close_for_schedule" class="media_modal_close">
						<span class="media_modal_icon">
							<span class="screen_reader_text">Close</span>
						</span>
					</button>
					<div class="edit_modal_content">
						<div id="menu_panel_for_schedule" class="media_frame_menu">
							<div id="media_menu_for_schedule" class="media_menu"></div>
						</div>
						<div id="media_title_for_schedule" class="media_frame_title">
							<h1 id="edit_title_for_schedule"></h1>
						</div>
						<div id="media_router_for_schedule" class="media_frame_router">
							<table class="tableNameList">
								
								<tr>
									<th>No</th>
									<td class="timeTd"><?php _e("Time", $pluginName); ?></td>
									<td><?php _e("Title", $pluginName); ?></td>
									<td class="td_width_50_px"><?php _e("Capacity", $pluginName); ?></td>
									<td id="remainder" class="td_width_50_px"><?php _e("Remainder", $pluginName); ?></td>
									<td id="stop" class="td_width_50_px"><?php _e("Stop", $pluginName); ?></td>
									<td id="allScheduleDelete" class="td_width_50_px"><?php _e("Delete", $pluginName); ?></td>
								</tr>
								
							</table>
							
						</div>
						<div id="media_frame_content_for_schedule"></div>
						
						<div id="edit_schedule_for_hotel" class="media_left_zero hidden_panel">
							<!--
							<div class="enablePanel">
								<div class="enableLabel"><?php _e("Booking acceptance", $pluginName); ?></div>
								<div class="enableValuePanel">
									<label><input type="checkbox" id="bookingEnable"/> <?php _e("Enable", $pluginName); ?></label>
								</div>
							</div>
							-->
							
							<table id="scheduleEditTable" class="table_option wp-list-table widefat fixed striped">
								<tr class="">
									<td class="">Date</td>
									<td class="">State</td>
									<td class="">Price</td>
									<td class="">Number of rooms available</td>
								</tr>
								
							</table>
							
						</div>
						
						<div id="email_edit_panel" class="media_left_zero hidden_panel">
							
							<div class="mail_message_area_left">
								<div class="enablePanel">
									<div class="enableLabel"><?php _e("Enable / Disable", $pluginName); ?></div>
									<div class="enableValuePanel">
										<label><input type="checkbox" id="mailEnable"/> <?php _e("Enable this email notification", $pluginName); ?></label>
									</div>
								</div>
								<div class="emailFormatPanel">
									<div class="emailFormatLabel"><?php _e("Email format", $pluginName); ?></div>
									<div class="emailFormatValuePanel">
										<label style="margin-right: 10px;"><input type="radio" id="emailFormatHtml" name="emailFormat" /> HTML</label>
										<label><input type="radio" id="emailFormatText" name="emailFormat" /> TEXT</label>
									</div>
								</div>
								<div>
									<input type="text" id="subject" class="mail_subject">
								</div>
								<?php 
									
									print '<div id="emailContentPanel" class="text_editer_panel">';
									wp_editor(
										"Content", "emailContent", 
										array(
											'media_buttons' => FALSE, 
											'textarea_rows' => 15, 
											'tinymce' => array(
												'remove_linebreaks' => false, 
												'force_br_newlines' => true, 
												'force_p_newlines' => false, 
												'gecko_spellcheck' => true,
												'convert_newlines_to_brs' => true,
											)
										)
									); 
									print '</div>';
									/**
									foreach($emailMessageList as $key => $mailMessage){
										
										$value = stripslashes($mailMessage['content']);
										print '<div id="'.$key.'_panel" class="text_editer_panel">';
										wp_editor($value, $key, array('media_buttons' => FALSE, 'textarea_rows' => 15)); 
										print '</div>';
										
									}
									**/
									
								?>
							</div>
							<div id="mail_message_area_right" class="mail_message_area_right"></div>
							
						</div>
						
						<div id="frame_toolbar_for_schedule" class="media_frame_toolbar">
							<div class="media_toolbar">
								<div id="buttonPanel_for_schedule" class="media_toolbar_primary">
									
								</div>
							</div>
						</div>
						
					</div>
					
				</div>
				
				<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
				
				<div id="timeSelectPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					
					<div id="selectPanelForConfirm" class="selectPanel">
						<div id="arror"></div>
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div id="confirm_body" class="body"></div>
						<div class="buttonPanel scheduleButtonPanel">
							<button id="dialogButtonReset" type="button" class="yesButton button button-primary" style="width: 70px; margin: 0;"><?php _e("Reset", $pluginName); ?></button>
							<button id="dialogButtonDone" type="button" class="noButton button button-primary" style="width: 70px; margin: 0;"><?php _e("Close", $pluginName); ?></button>
						</div>
					</div>
					
				</div>
				
				<div id="dialogPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					<div class="confirmPanel">
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div class="body"><?php _e("Message", $pluginName); ?></div>
						<div class="buttonPanel">
							<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
							<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
						</div>
					</div>
				</div>
				
				
			<!--
			<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
			-->
			<div id="loadingPanel" class="">
				<div class="loader">
					<svg viewBox="0 0 64 64" width="64" height="64">
						<circle id="spinner" cx="32" cy="32" r="28" fill="none"></circle>
					</svg>
				</div>
			</div>
			<?php
			
			#print '<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="'.plugin_dir_url( __FILE__ ).'images/loading_0.gif"></div>';
			
		}
		
		public function setting_page(){
			
			$this->update_database();
			$timezone = get_option('timezone_string');
			date_default_timezone_set($timezone);
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			$setting = new setting($this->prefix, $this->plugin_name);
			
			$booking_sync = $setting->getBookingSyncList();
			
			/**
			$list = $setting->getList();
			$booking_sync = $setting->getBookingSyncList();
			$emailMessageList = $setting->getEmailMessage();
			$courseList = $setting->getCourseList();
			$courseData = $setting->getCourseData();
			$formInputType = $setting->getFormInputType();
			$formData = $setting->getForm();
			$countries = json_decode(file_get_contents(plugin_dir_path( __FILE__ ).'lib/Countries_with_Regional_Codes.json'), true);
			$list['General'][$this->prefix.'country']['valueList'] = $countries;
			
			$booking_sync['Google_Calendar']['parse_url'] = parse_url(get_home_url());
			$booking_sync['iCal']['booking_package_ical_token']['home'] = get_home_url();
			if(is_null($booking_sync['iCal']['booking_package_ical_token']['value']) === true || strlen($booking_sync['iCal']['booking_package_ical_token']['value']) == 0){
				
				$tokenResponse = $setting->refreshToken("booking_package_ical_token");
				$booking_sync['iCal']['booking_package_ical_token']['value'] = $tokenResponse['token'];
				
			}
			
			
			$locale = get_locale();
			$dictionary = $this->getDictionary("setting_page", $this->plugin_name);
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_control, 
				'nonce' => wp_create_nonce($this->action_control."_ajax"), 
				'locale' => $locale,
				'list' => $list, 
				'bookingSyncList' => $booking_sync, 
				"extension_url" => BOOKING_PACKAGE_EXTENSION_URL, 
				'courseData' => $courseData, 
				'courseList' => $courseList, 
				'formInputType' => $formInputType, 
				'formData' => $formData, 
				'emailMessageList' => $emailMessageList,
				'is_mobile' => $this->is_mobile,
			);
			**/
			
			$dictionary = $this->getDictionary("setting_page", $this->plugin_name);
			$localize_script = $this->localizeScript("setting_page");
			$p_v = "?p_v=".$this->plugin_version;
			wp_enqueue_style('wp-color-picker');
			wp_enqueue_style( 'setting_page', plugin_dir_url( __FILE__ ).'css/Control.css', array(), $this->plugin_version);
			wp_enqueue_style( 'control_for_madia_css', plugin_dir_url( __FILE__ ).'css/Control_for_madia.css', array(), $this->plugin_version);
			$fontFaceStyle = $this->getFontFaceStyle();
            wp_add_inline_style("Control.css", $fontFaceStyle);
			
			$subscriptions = $this->getSubscriptions();
			foreach($subscriptions as $key => $value){
				
				if($key == 'expiration_date_for_subscriptions'){
					
					$localize_script['expiration_date'] = date('F d, Y H:i', $value);
					
				}
				
				$localize_script[$key] = $value;
				
			}
			
			
			
			$isExtensionsValid = $setting->extensionFunction();
			wp_print_scripts( array( 'jquery-ui-sortable' ));
			wp_enqueue_script( 'Error_js', plugin_dir_url( __FILE__ ).'js/Error.js'.$p_v);
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js'.$p_v);
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js'.$p_v);
			wp_enqueue_script( 'input_js', plugin_dir_url( __FILE__ ).'js/Input.js'.$p_v);
			wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js'.$p_v);
			wp_enqueue_script( 'setting_page', plugin_dir_url( __FILE__ ).'js/setting.js'.$p_v, array('jquery', 'wp-color-picker'));
			wp_localize_script('setting_page', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('setting_page', 'setting_data', $localize_script);
			wp_localize_script('setting_page', $this->prefix.'countries', $countries);
			
			$pluginName = $this->plugin_name;
			
			
			?>
				
				<div class="wrap">
					
					<div id="tabFrame">
						<div style="overflow-x: auto;">
						<div class="menuList">
							<div id="settingLink" class="menuItem active"><?php _e("Setting", $pluginName); ?></div>
							
							<!--
							<div id="formLink" class="menuItem"><?php _e("Form fields", $pluginName); ?></div>
							<div id="courseLink" class="menuItem"><?php _e("Services", $pluginName); ?></div>
							<div id="emailLink" class="menuItem"><?php _e("Emails message", $pluginName); ?></div>
							-->
							
							<div id="syncLink" class="menuItem"><?php _e("Sync", $pluginName); ?></div>
							<div id="subscriptionLink" class="menuItem"><?php _e("Subscription details", $pluginName); ?></div>
						</div>
						</div>
						<div id="contentPanel" class="content">
							<div id="settingPanel">
								<div id="setting_table"></div>
								<div><button id="save_setting" type="button" class="w3tc-button-save button-primary"><?php _e("Save all settings", $pluginName); ?></button></div>
							</div>
							<!--
							<div id="formPanel" class="hidden_panel">formPanel</div>
							<div id="coursePanel" class="hidden_panel">coursePanel</div>
							<div id="emailPanel" class="hidden_panel">
								<div id="mailSettingPanel">
									
									<div id="mailSettingButtonPanel"></div>
										
									<div id="content_area">
										
									</div>
									<div>
										
										
									</div>
								</div>
							</div>
							-->
							<div id="syncPanel" class="hidden_panel">
								<div id="bookingSync_table"></div>
								<div><button id="save_bookingSync" type="button" class="w3tc-button-save button-primary"><?php _e("Save all settings", $pluginName); ?></button></div>
							</div>
							<div id="subscriptionPanel" class="hidden_panel"></div>
							
						</div>
					</div>
					
				</div>
				
				
				<div id="editPanel" class="edit_modal hidden_panel">
					<button type="button" id="media_modal_close" class="media_modal_close">
						<span class="">
							<span class="material-icons">close</span>
						</span>
					</button>
					<div class="edit_modal_content">
						<div id="media_title" class="media_left_zero"><h1 id="edit_title"></h1></div>
						<div id="media_router" class="media_left_zero">
							<div class="table_row">
								
							</div>
						</div>
						<div id="media_frame_content" class="media_left_zero content_top_48">
							
							<!--
							<div class="mail_message_area_left">
								
								<div class="enablePanel">
									<div class="enableLabel"><?php _e("Enable / Disable", $pluginName); ?></div>
									<div class="enableValuePanel">
										<label><input type="checkbox" id="mailEnable"/> <?php _e("Enable this email notification", $pluginName); ?></label>
									</div>
								</div>
								<div class="emailFormatPanel">
									<div class="emailFormatLabel"><?php _e("Email format", $pluginName); ?></div>
									<div class="emailFormatValuePanel">
										<label style="margin-right: 10px;"><input type="radio" id="emailFormatHtml" name="emailFormat" /> HTML</label>
										<label><input type="radio" id="emailFormatText" name="emailFormat" /> TEXT</label>
									</div>
								</div>
								<div>
									<input type="text" id="subject" class="mail_subject">
								</div>
								<?php 
									
									foreach($emailMessageList as $key => $mailMessage){
										
										$value = stripslashes($mailMessage['content']);
										print '<div id="'.$key.'_panel" class="text_editer_panel">';
										wp_editor($value, $key, array('media_buttons' => FALSE, 'textarea_rows' => 15)); 
										print '</div>';
										
									}	
								?>
							</div>
							<div id="mail_message_area_right" class="mail_message_area_right">
								
							</div>
							-->
						</div>
						<div id="frame_toolbar" class="media_frame_toolbar media_left_zero">
							<div class="media_toolbar">
								<div class="media_toolbar_primary">
									<button id="mail_message_save_button" type="button" class="button media-button button-primary button-large media-button-insert"><?php _e("Save", $pluginName); ?></button>
								</div>
							</div>
						</div>
						
					</div>
					
				</div>
				
				<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
				
				<div id="dialogPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					<div class="confirmPanel">
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div class="body"><?php _e("Message", $pluginName); ?></div>
						<div class="buttonPanel">
							<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
							<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
						</div>
					</div>
				</div>
				
				<div id="google_calendar_api" class="hidden_panel">
					
					<div>
						<?php _e("The Google Calendar API lets you share customer information between the Booking Package and Google Calendar.", $pluginName); ?>
						<?php _e("When you create or edit a new event in Google Calendar, it will also be sent to the booking package.", $pluginName); ?><br>
						<?php _e('For details on how to set up please read that <a id="googleCalendarLink" href="https://saasproject.net/googleCalendar/" target="_blank">how to set up sync for Booking Package and Google Calendar</a>. ', $pluginName); ?>
					</div>
					
				</div>
				<!--
				<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
				-->
				<div id="loadingPanel" class="">
					<div class="loader">
						<svg viewBox="0 0 64 64" width="64" height="64">
							<circle id="spinner" cx="32" cy="32" r="28" fill="none"></circle>
						</svg>
					</div>
				</div>
			<?php
			
			
		}
		
		public function update_data($key, $value){
			
			if(get_option($key) === false){
							
				add_option($key, $value);
					
			}else{
				
				update_option($key, $value);
				
			}
			
		}
		
		public function wp_ajax_booking_package_for_public(){
			
			if(isset($_POST['nonce']) && check_ajax_referer($this->action_public."_ajax", 'nonce', false)){
				
				
				$timezone = get_option('timezone_string');
            	date_default_timezone_set($timezone);
            	#var_dump($timezone);
            	
            	require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/CreditCard.php');
				$schedule = new Schedule($this->prefix, $this->plugin_name);
				
            	$response = array('status' => 'error', 'mode' => $_POST['mode']);
            	
            	if($_POST['mode'] == 'getReservationData'){
            		
					$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year'], false, true);
            		
            	}
            	
            	if($_POST['mode'] == 'sendBooking'){
            		
					$response = $schedule->sendBooking();
            		
            	}
            	
            	if($_POST['mode'] == 'scriptError'){
					
					$response = $schedule->scriptError();
					
				}
            	
				print json_encode($response);
				
			}else{
				
				print json_encode(array('status' => 'error'));
				
			}
			
			die();
			
		}
		
		public function wp_ajax_booking_package(){
			
			if(isset($_POST['nonce']) && check_ajax_referer($this->action_control."_ajax", 'nonce')){
				
				#print "ok";
				/**
				$timezone = get_option('timezone_string');
            	date_default_timezone_set($timezone);
				
				$response = array('status' => 'error', 'mode' => $_POST['mode']);
				
				require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/CreditCard.php');
				
				$setting = new setting($this->prefix, $this->plugin_name);
				$schedule = new Schedule($this->prefix, $this->plugin_name);
				
				if($_POST['mode'] == 'setting'){
					
					$response = $setting->update($_POST);
					$response['status'] = 'success';
					
				}
				
				if($_POST['mode'] == 'refreshToken'){
					
					$response = $setting->refreshToken($_POST['key']);
					
				}
				
				if($_POST['mode'] == 'getCourseList'){
					
					$response = $setting->getCourseList($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'addCourse'){
					
					$response = $setting->addCourse($_POST);
					
				}
				
				if($_POST['mode'] == 'updateCourse'){
					
					$response = $setting->updateCourse($_POST);
					
				}
				
				if($_POST['mode'] == 'getGuestsList'){
					
					$response = $setting->getGuestsList($_POST['accountKey']);
					
					
				}
				
				if($_POST['mode'] == 'updateGuests'){
					
					$response = $setting->updateGuests($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'addGuests'){
					
					$response = $setting->addGuests($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'deleteGuestsItem'){
					
					$response = $setting->deleteGuestsItem($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'changeGuestsRank'){
					
					$response = $setting->changeGuestsRank($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'deleteCourse'){
					
					$response = $setting->deleteCourse($_POST);
					
				}
				
				if($_POST['mode'] == 'changeCourseRank'){
					
					$response = $setting->changeCourseRank($_POST);
					
				}
				
				if($_POST['mode'] == 'getForm'){
					
					$response = $setting->getForm($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'addForm'){
					
					$response = $setting->addForm($_POST);
					
				}
				
				if($_POST['mode'] == 'updateForm'){
					
					$response = $setting->updateForm($_POST);
					
				}
				
				if($_POST['mode'] == 'deleteFormItem'){
					
					$response = $setting->deleteFormItem($_POST);
					
				}
				
				if($_POST['mode'] == 'changeFormRank'){
					
					$response = $setting->changeFormRank($_POST);
					
				}
				
				if($_POST['mode'] == 'updataEmailMessageForCalendarAccount'){
					
					$response = $setting->updataEmailMessageForCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'updataEmailMessage'){
					
					$response = $setting->updataEmailMessage($_POST['key'], $_POST['subject'], $_POST['content'], $_POST['enable'], $_POST['format']);
					
				}
				
				if($_POST['mode'] == 'upgradePlan'){
					
					$response = $setting->upgradePlan($_POST['type']);
					
				}
				
				if($_POST['mode'] == 'getEmailMessageList' && isset($_POST['accountKey'])){
					
					$response = $setting->getEmailMessageList($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'getTemplateSchedule'){
					
					$response = $schedule->getTemplateSchedule($_POST['weekKey']);
					
				}
				
				if($_POST['mode'] == 'getRangeOfSchedule'){
					
					$response = $schedule->getRangeOfSchedule($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'updateRangeOfSchedule'){
					
					$response = $schedule->updateRangeOfSchedule($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'getPublicSchedule'){
					
					$response = $schedule->getPublicSchedule();
					
				}
				
				if($_POST['mode'] == 'getCalendarAccountListData'){
					
					$response = $schedule->getCalendarAccountListData();
					
				}
				
				if($_POST['mode'] == 'addCalendarAccount'){
					
					$response = $schedule->addCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'updateCalendarAccount'){
					
					$response = $schedule->updateCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'deleteCalendarAccount'){
					
					$response = $schedule->deleteCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'getAccountScheduleData'){
					
					$response = $schedule->getAccountScheduleData();
					
				}
				
				if($_POST['mode'] == 'updateAccountTemplateSchedule'){
					
					$list = $schedule->updateAccountTemplateSchedule();
					
					$response['status'] = 'success';
					
				}
				
				if($_POST['mode'] == 'updateAccountSchedule'){
					
					$list = $schedule->updateAccountSchedule();
					
					$response['status'] = 'success';
					
				}
				
				if($_POST['mode'] == 'getReservationData'){
					
					if(isset($_POST['accountKey'])){
						
						#booking_package_accountKey
						$expire = date('U') + (30 * 24 * 3600);
						setcookie($this->prefix.'accountKey', $_POST['accountKey'], $expire);
						$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year']);
						$response['formData'] = $setting->getForm($_POST['accountKey']);
						$response['courseList'] = $setting->getCourseList($_POST['accountKey']);
						$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
						$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
						
					}else{
						
						$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year']);
						
					}
					
					
					
				}
				
				if($_POST['mode'] == 'sendBooking'){
					
					$response = $schedule->sendBooking();
					$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
					$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'deleteBookingData'){
					
					$response = $schedule->deleteBookingData($_POST['key']);
					$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
					$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'updateBooking'){
					
					$response = $schedule->updateBooking();
					$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
					$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'updateStatus'){
					
					$response = $schedule->updateStatus();
					if(intval($_POST['reload']) == 1){
						$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
						$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
					}
					
				}
				**/
				
				$response = $this->choeseMode();
				print json_encode($response);
				
			}
			
			die();
			
		}
		
		public function choeseMode(){
			
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
			
			$response = array('status' => 'error', 'mode' => $_POST['mode']);
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/CreditCard.php');
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			
			if($_POST['mode'] == 'setting'){
				
				$response = $setting->update($_POST);
				$response['status'] = 'success';
				
			}
			
			if($_POST['mode'] == 'refreshToken'){
				
				$response = $setting->refreshToken($_POST['key']);
				
			}
				
			if($_POST['mode'] == 'getCourseList'){
				
				$response = $setting->getCourseList($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'addCourse'){
				
				$response = $setting->addCourse($_POST);
				
			}
			
			if($_POST['mode'] == 'updateCourse'){
				
				$response = $setting->updateCourse($_POST);
				
			}
			
			if($_POST['mode'] == 'getGuestsList'){
				
				$response = $setting->getGuestsList($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'updateGuests'){
				
				$response = $setting->updateGuests($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'addGuests'){
				
				$response = $setting->addGuests($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'deleteGuestsItem'){
				
				$response = $setting->deleteGuestsItem($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'changeGuestsRank'){
				
				$response = $setting->changeGuestsRank($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'deleteCourse'){
				
				$response = $setting->deleteCourse($_POST);
				
			}
			
			if($_POST['mode'] == 'changeCourseRank'){
				
				$response = $setting->changeCourseRank($_POST);
				
			}
			
			if($_POST['mode'] == 'getForm'){
				
				$response = $setting->getForm($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'addForm'){
				
				$response = $setting->addForm($_POST);
				
			}
			
			if($_POST['mode'] == 'updateForm'){
				
				$response = $setting->updateForm($_POST);
				
			}
			
			if($_POST['mode'] == 'deleteFormItem'){
				
				$response = $setting->deleteFormItem($_POST);
				
			}
			
			if($_POST['mode'] == 'changeFormRank'){
				
				$response = $setting->changeFormRank($_POST);
				
			}
			
			if($_POST['mode'] == 'updataEmailMessageForCalendarAccount'){
				
				$response = $setting->updataEmailMessageForCalendarAccount();
				
			}
			
			if($_POST['mode'] == 'updataEmailMessage'){
				
				$response = $setting->updataEmailMessage($_POST['key'], $_POST['subject'], $_POST['content'], $_POST['enable'], $_POST['format']);
				
			}
			
			if($_POST['mode'] == 'upgradePlan'){
				
				$response = $setting->upgradePlan($_POST['type']);
				
			}
			
			if($_POST['mode'] == 'getEmailMessageList' && isset($_POST['accountKey'])){
				
				$response = $setting->getEmailMessageList($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'scriptError'){
				
				$response = $schedule->scriptError();
				
			}
			
			if($_POST['mode'] == 'getTemplateSchedule'){
				
				$response = $schedule->getTemplateSchedule($_POST['weekKey']);
				
			}
			
			if($_POST['mode'] == 'getRangeOfSchedule'){
				
				$response = $schedule->getRangeOfSchedule($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'updateRangeOfSchedule'){
				
				$response = $schedule->updateRangeOfSchedule($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'getPublicSchedule'){
				
				$response = $schedule->getPublicSchedule();
				
			}
			
			if($_POST['mode'] == 'getCalendarAccountListData'){
				
				$response = $schedule->getCalendarAccountListData();
				
			}
			
			if($_POST['mode'] == 'addCalendarAccount'){
				
				$response = $schedule->addCalendarAccount();
				
			}
			
			if($_POST['mode'] == 'updateCalendarAccount'){
				
				$response = $schedule->updateCalendarAccount();
				
			}
			
			if($_POST['mode'] == 'deleteCalendarAccount'){
				
				$response = $schedule->deleteCalendarAccount();
				
			}
			
			if($_POST['mode'] == 'getAccountScheduleData'){
				
				$response = $schedule->getAccountScheduleData();
				
			}
			
			if($_POST['mode'] == 'updateAccountTemplateSchedule'){
				
				$list = $schedule->updateAccountTemplateSchedule();
				$response['status'] = 'success';
				
			}
			
			if($_POST['mode'] == 'updateAccountSchedule'){
				
				$list = $schedule->updateAccountSchedule();
				$response['status'] = 'success';
				
			}
			
			if($_POST['mode'] == 'getReservationData'){
				
				if(isset($_POST['accountKey'])){
					
					#booking_package_accountKey
					$expire = date('U') + (30 * 24 * 3600);
					setcookie($this->prefix.'accountKey', $_POST['accountKey'], $expire);
					$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year']);
					$response['formData'] = $setting->getForm($_POST['accountKey']);
					$response['courseList'] = $setting->getCourseList($_POST['accountKey']);
					$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
					$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
					
				}else{
					
					$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year']);
					
				}
				
			}
			
			if($_POST['mode'] == 'getDownloadCSV'){
				
				$response = $schedule->getDownloadCSV();
				
			}
			
			if($_POST['mode'] == 'sendBooking'){
				
				$response = $schedule->sendBooking();
				$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
				$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'deleteBookingData'){
				
				$response = $schedule->deleteBookingData($_POST['key']);
				$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
				$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'updateBooking'){
				
				$response = $schedule->updateBooking();
				$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
				$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
				
			}
			
			if($_POST['mode'] == 'updateStatus'){
				
				$response = $schedule->updateStatus();
				if(intval($_POST['reload']) == 1){
					$response['guestsList'] = $setting->getGuestsList($_POST['accountKey'], true);
					$response['account'] = $schedule->getCalendarAccount($_POST['accountKey']);
				}
					
			}
				
			#print json_encode($response);
			return $response;
			
		}
		
		public function getSubscriptions(){
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$subscriptions = $setting->upgradePlan('get');
			unset($subscriptions["status"]);
			return $subscriptions;
			
		}
		
		public function upgradeButton($isExtensionsValid = false){
			
			if($isExtensionsValid === true){
				
				return $isExtensionsValid;
				
			}
			
			$uri = plugin_dir_url( __FILE__ );
			$parse_url = parse_url($uri);
			$locale = get_locale();
			$dictionary = $this->getDictionary("Upgrade_js", $this->plugin_name);
			
			$timezone = get_option('timezone_string');
			$upgradeDetail = array("extension_url" => BOOKING_PACKAGE_EXTENSION_URL, "timeZone" => get_option('timezone_string'), "local" => get_locale(), "site" => get_site_url(), "stripe_public_key" => BOOKING_PACKAGE_STRIPE_PUBLIC_KEY, "locale" => $locale);
			
			$subscriptions = $this->getSubscriptions();
			foreach($subscriptions as $key => $value){
				
				$upgradeDetail[$key] = $value;
				
			}
			
			$upgradeDetail['secure'] = 0;
			if($parse_url['scheme'] == 'https'){
				
				$upgradeDetail['secure'] = 1;
				
			}
			#$pluginUrl = $_SERVER['HTTP_X_FORWARDED_PROTO'].'://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
			$pluginUrl = (empty($_SERVER["HTTPS"]) ? "http://" : "https://") . $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];
			$upgradeDetail['pluginUrl'] = $pluginUrl;
			
			wp_enqueue_script('stripe_checkout_js', 'https://checkout.stripe.com/checkout.js');
			wp_enqueue_script('stripe_checkout_v3_js', 'https://js.stripe.com/v3/');
			wp_enqueue_script('Upgrade_js', plugin_dir_url( __FILE__ ).'js/Upgrade.js');
			wp_localize_script('Upgrade_js', 'upgrade_dictionary', $dictionary);
			wp_localize_script('Upgrade_js', 'upgradeDetail', $upgradeDetail);
			
			$pluginName = $this->plugin_name;
			
			print '<button id="upgradeButton" class="media-button button-primary button-large media-button-insert">'.__('Upgrade', $pluginName).'</button>';
			?>
			
			<div id="upgradePanel" class="edit_modal hidden_panel">
				<button type="button" id="upgrade_media_modal_close" class="media_modal_close">
					<span class="media_modal_icon"><span class="material-icons">close</span></span>
				</button>
				<div class="edit_modal_content">
					<div id="upgrade_menu_panel" class="media_frame_menu">
						<div id="upgrade_media_menu" class="media_menu"></div>
					</div>
					<div id="upgrade_media_title" class="media_frame_title"><h1 id="upgrade_edit_title"><?php _e('Upgrade', $pluginName); ?></h1></div>
					<div id="upgrade_media_router" class="media_frame_router">
						<div id="upgrade_content_panel">
							
						</div>
					</div>
					<div id="upgrade_frame_toolbar" class="media_frame_toolbar">
						<div class="media_toolbar">
							<div id="upgrade_buttonPanel" class="media_toolbar_primary" style="float: initial;">
								<div id="upgrade_leftButtonPanel"></div>
								<div id="upgrade_rightButtonPanel"></div>
							</div>
						</div>
					</div>
					
				</div>
				
			</div>
			
			<div id="upgrade_blockPanel" class="edit_modal_backdrop hidden_panel"></div>
			
			<?php
			
		}
		
		public function ical_feeds(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Ical.php');
			
			$ical = new iCal($this->prefix);
			$ical->isValid($_GET['ical']);
			
			
			
		}
		
		public function webhook(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Webhook.php');
			
			$target = sanitize_text_field($_GET["weebhook"]);
			$HTTP_X_GOOG_CHANNEL_ID = sanitize_text_field($_SERVER['HTTP_X_GOOG_CHANNEL_ID']);
			$HTTP_X_GOOG_CHANNEL_TOKEN = sanitize_text_field($_SERVER['HTTP_X_GOOG_CHANNEL_TOKEN']);
			
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$googleCalendarDeteils = $schedule->lookingForGoogleCalendarId($HTTP_X_GOOG_CHANNEL_ID);
			
			#lookingForGoogleCalendarId
			#if(get_option($this->prefix."id_for_google_webhook") == $HTTP_X_GOOG_CHANNEL_ID && get_option($this->prefix."token_for_google_webhook") == $HTTP_X_GOOG_CHANNEL_ID){
			
			if($googleCalendarDeteils['idForGoogleWebhook'] == $HTTP_X_GOOG_CHANNEL_ID){
				
				$webhook = new Webhook($this->prefix, $this->plugin_name);
				$webhook->catchWebhook($target, $HTTP_X_GOOG_CHANNEL_ID, $_POST);
				exit;
				
			}
			
		}
		
		public function localizeScript($mode){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Webhook.php');
            require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
            
            $schedule = new Schedule($this->prefix, $this->plugin_name);
            $setting = new setting($this->prefix, $this->plugin_name);
            $locale = get_locale();
            $javascriptSyntaxErrorNotification = get_option($this->prefix."javascriptSyntaxErrorNotification", 1);
            
            $javascriptFileslist = array();
            $dir = plugin_dir_path( __FILE__ ).'js/';
			if($handle = opendir($dir)){
				
				while(($file = readdir($handle)) !== false){
					
					if(filetype($path = $dir.$file) == "file"){
						
						array_push($javascriptFileslist, $file);
						
					}
					
				}
				
			}
            
            
            $localize_script = array();
			if($mode == 'adomin'){
				
				$dashboardRequest = array('status' => 0);
				if(isset($_GET['key']) && isset($_GET['calendar']) && isset($_GET['month']) && isset($_GET['day']) && isset($_GET['year'])){
					
					$dashboardRequest = array(
						'status' => 1, 
						'key' => intval($_GET['key']), 
						'calendar' => intval($_GET['calendar']), 
						'month' => intval($_GET['month']), 
						'day' => intval($_GET['day']), 
						'year' => intval($_GET['year'])
					);
					
				}
				
				
				$list = $setting->getList();
				$courseList = $setting->getCourseList();
				$emailMessageList = $setting->getEmailMessage(array('enable'));
				$formData = $setting->getForm();
				
				$courseBool = get_option($this->prefix."courseBool", "false");
				$courseName = get_option($this->prefix."courseName", "false");
				$dateFormat = get_option($this->prefix."dateFormat", "0");
				$positionOfWeek = get_option($this->prefix."positionOfWeek", "before");
				
				$localize_script = array(
					'url' => admin_url('admin-ajax.php'), 
					'action' => $this->action_control, 
					'nonce' => wp_create_nonce($this->action_control."_ajax"), 
					'prefix' => $this->prefix,
					'courseBool' => $courseBool, 
					'courseName' => $courseName, 
					'year' => date('Y'), 
					'month' => date('m'), 
					'day' => date('d'), 
					'locale' => $locale,
					'courseList' => $courseList, 
					'country' => $list['General']['booking_package_country']['value'],
					'currency' => $list['General']['booking_package_currency']['value'],
					'dateFormat' => $dateFormat,
					'positionOfWeek' => $positionOfWeek,
					'formData' => $formData,
					'calendarAccountList' => $schedule->getCalendarAccountListData(),
					'is_mobile' => $this->is_mobile,
					'dashboardRequest' => $dashboardRequest,
					'bookingBool' => 1,
					'emailEnable' => $emailMessageList,
					'javascriptSyntaxErrorNotification' => $javascriptSyntaxErrorNotification,
					'javascriptFileslist' => $javascriptFileslist,
				);
				
				
			}else if($mode == 'schedule_page'){
				
				$courseData = $setting->getCourseData();
				$formInputType = $setting->getFormInputType();
				$emailMessageList = $setting->getEmailMessage();
				
				$schedule->deleteOldDaysInSchedules();
				$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
				
				$dateFormat = get_option($this->prefix."dateFormat", "0");
				$courseBool = get_option($this->prefix."courseBool", "false");
				$positionOfWeek = get_option($this->prefix."positionOfWeek", "before");
				
				$elementForCalendarAccount = $setting->getElementForCalendarAccount();
				
				$localize_script = array(
					'url' => admin_url('admin-ajax.php'), 
					'action' => $this->action_control, 
					'nonce' => wp_create_nonce($this->action_control."_ajax"), 
					'courseBool' => $courseBool, 
					'year' => date('Y'), 
					'month' => date('m'), 
					'locale' => $locale, 
					'dateFormat' => $dateFormat, 
					'positionOfWeek' => $positionOfWeek,
					'list' => $list, 
					'formInputType' => $formInputType, 
					'courseData' => $courseData,
					'elementForCalendarAccount' => $elementForCalendarAccount, 
					'guestsInputType' => $setting->guestsInputType(),
					'is_mobile' => $this->is_mobile,
					'javascriptSyntaxErrorNotification' => $javascriptSyntaxErrorNotification,
					'javascriptFileslist' => $javascriptFileslist,
				);
				
			}else if($mode == 'setting_page'){
				
				$list = $setting->getList();
				$booking_sync = $setting->getBookingSyncList();
				$emailMessageList = $setting->getEmailMessage();
				$courseList = $setting->getCourseList();
				$courseData = $setting->getCourseData();
				$formInputType = $setting->getFormInputType();
				$formData = $setting->getForm();
				$countries = json_decode(file_get_contents(plugin_dir_path( __FILE__ ).'lib/Countries_with_Regional_Codes.json'), true);
				$list['General'][$this->prefix.'country']['valueList'] = $countries;
				
				$booking_sync['Google_Calendar']['parse_url'] = parse_url(get_home_url());
				$booking_sync['iCal']['booking_package_ical_token']['home'] = get_home_url();
				if(is_null($booking_sync['iCal']['booking_package_ical_token']['value']) === true || strlen($booking_sync['iCal']['booking_package_ical_token']['value']) == 0){
					
					$tokenResponse = $setting->refreshToken("booking_package_ical_token");
					$booking_sync['iCal']['booking_package_ical_token']['value'] = $tokenResponse['token'];
					
				}
				
				$localize_script = array(
					'url' => admin_url('admin-ajax.php'), 
					'action' => $this->action_control, 
					'nonce' => wp_create_nonce($this->action_control."_ajax"), 
					'locale' => $locale,
					'list' => $list, 
					'bookingSyncList' => $booking_sync, 
					"extension_url" => BOOKING_PACKAGE_EXTENSION_URL, 
					'courseData' => $courseData, 
					'courseList' => $courseList, 
					'formInputType' => $formInputType, 
					'formData' => $formData, 
					'emailMessageList' => $emailMessageList,
					'is_mobile' => $this->is_mobile,
					'javascriptSyntaxErrorNotification' => $javascriptSyntaxErrorNotification,
					'javascriptFileslist' => $javascriptFileslist,
				);
				
			}else if($mode == 'visitor'){
				
				$list = $setting->getList();
				$courseList = $setting->getCourseList();
				$emailMessageList = $setting->getEmailMessage(array('enable'));
				$formData = $setting->getForm();
				
				$courseBool = get_option($this->prefix."courseBool", "false");
				$courseName = get_option($this->prefix."courseName", "false");
				$dateFormat = get_option($this->prefix."dateFormat", "0");
				$positionOfWeek = get_option($this->prefix."positionOfWeek", "before");
				
				$localize_script = array(
					'url' => admin_url('admin-ajax.php'), 
					#'url' => plugin_dir_url( __FILE__ ).'ajax.php',
					'action' => $this->action_public, 
					'nonce' => wp_create_nonce($this->action_public."_ajax"), 
					'courseBool' => $courseBool, 
					'year' => date('Y'), 
					'month' => date('m'), 
					'day' => date('d'), 
					'courseList' => $courseList, 
					'country' => $list['General']['booking_package_country']['value'],
					'currency' => $list['General']['booking_package_currency']['value'],
					'dateFormat' => $dateFormat,
					'positionOfWeek' => $positionOfWeek,
					'formData' => $formData,
					'locale' => $locale,
					'is_mobile' => $this->is_mobile,
					'javascriptSyntaxErrorNotification' => $javascriptSyntaxErrorNotification,
					'javascriptFileslist' => $javascriptFileslist,
				);
				
			}
			
			$localize_script['referer_field'] = esc_attr(wp_unslash($_SERVER['REQUEST_URI']));
			
			return $localize_script;
			
		}
		
		public function api(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			if(isset($_POST['mode'])){
				
				if(isset($_POST['access_status']) && $_POST['access_status'] == 'public'){
					
					if($_POST['mode'] == 'getNonce' && isset($_POST['accountKey'])){
						
						$locale = get_locale();
						$response = array(
							'action' => $this->action_public, 
							'nonce' => wp_create_nonce($this->action_public."_ajax"), 
						);
						
						$accountKey = $_POST['accountKey'];
						
						$setting = new setting($this->prefix, $this->plugin_name);
						$list = $setting->getList();
						$courseList = $setting->getCourseList($accountKey);
						$formData = $setting->getForm($accountKey);
						$guestsList = $setting->getGuestsList($accountKey, true);
						for($i = 0; $i < count($guestsList); $i++){
							
							$decode = json_decode($guestsList[$i]['json'], true);
							$guestsList[$i]['json'] = $decode;
							
						}
						
						$schedule = new Schedule($this->prefix, $this->plugin_name);
						$schedule->deleteOldDaysInSchedules();
						$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
						
						#$courseBool = get_option($this->prefix."courseBool", "false");
						#$courseName = get_option($this->prefix."courseName", "false");
						$dateFormat = get_option($this->prefix."dateFormat", "0");
						$positionOfWeek = get_option($this->prefix."positionOfWeek", "before");
						
						$calendarAccount = $schedule->getCalendarAccount($accountKey);
						$courseBool = "false";
						if(intval($calendarAccount["courseBool"]) == 1){
							
							$courseBool = "true";
							
						}
						
						$style = $this->getStyle($list);
						
						$dictionary = $this->getDictionary("bookingPageForVisitors", $this->plugin_name);
						$localize_script = array(
							'url' => admin_url('admin-ajax.php'), 
							'action' => $this->action_public, 
							'nonce' => wp_create_nonce($this->action_public."_ajax"), 
							'courseBool' => $courseBool, 
							'courseName' => $calendarAccount["courseTitle"], 
							'year' => date('Y'), 
							'month' => date('m'), 
							'day' => date('d'), 
							'courseList' => $courseList, 
							'currency' => $list['General']['booking_package_currency']['value'],
							'dateFormat' => $dateFormat,
							'positionOfWeek' => $positionOfWeek,
							'formData' => $formData,
							'locale' => $locale,
							'dictionary' => $dictionary,
							'accountKey' => $accountKey,
							'calendarAccount' => $calendarAccount,
							'guestsList' => $guestsList,
							'is_mobile' => $this->is_mobile,
							'style' => $this->getStyle($list),
							'javascriptSyntaxErrorNotification' => $javascriptSyntaxErrorNotification,
							'javascriptFileslist' => $javascriptFileslist,
						);
						
						if(intval(get_option($this->prefix."stripe_active", 0)) == 1){
							
							$stripe_public_key = get_option($this->prefix."stripe_public_key", null);
							if(!is_null($stripe_public_key)){
								
								$localize_script['stripe_active'] = 1;
								$localize_script['stripe_public_key'] = $stripe_public_key;
								
							}else{
								
								$localize_script['stripe_active'] = 0;
								
							}
							
						}else{
							
							$localize_script['stripe_active'] = 0;
							
						}
						
						print json_encode($localize_script);
						
					}else{
						
						$this->wp_ajax_booking_package_for_public();
						
					}
					
				}
				
				
				exit;
				
			}
			
		}
		
		public function app(){
			
			if($this->webApp == 0){
				
				print json_encode(array('status' => 'error'));
				die();
				
			}
			
			$p_v = "?p_v=".$this->plugin_version;
			header("Connection:Keep-Alive");
			header("Access-Control-Allow-Origin: *");
			
			if($_POST['app'] == 'download' || $_GET['app'] == 'download'){
				
				if($_POST['type'] == 'js' || $_GET['type'] == 'js'){
					
					header("Content-type: application/javascript; charset=utf-8");
					
				}else if($_POST['type'] == 'css' || $_GET['type'] == 'css'){
					
					header("Content-type: text/css; charset=utf-8");
					
				}
				
				
				$fileName = sanitize_text_field($_POST['file']);
				if(isset($_GET['file'])){
					
					$fileName = sanitize_text_field($_GET['file']);
					
				}
				
				$fileList = array();
				$dirList = array(plugin_dir_path( __FILE__ ).'js/', plugin_dir_path( __FILE__ ).'css/');
				for($i = 0; $i < count($dirList); $i++){
					
					$dir = $dirList[$i];
					if(is_dir($dir) && $handle = opendir($dir)){
						
						while(($file = readdir($handle)) !== false){
							
							if(filetype($path = $dir.$file) == "file"){
								
								$fileList[$file] = $path;
								
							}
							
						}
						
					}
					
				}
				
				if(isset($fileList[$fileName])){
					
					header('Content-Disposition: attachment; filename="'.$fileName.'"');
					$text = file_get_contents($fileList[$fileName]);
					print $text;
					
				}
				
			}else if($_POST['app'] == 'signon' || $_GET['app'] == 'signon'){
				
				header("Content-type: application/json; charset=utf-8");
				$response = $this->appLogin();
				header("Access-Control-Allow-Origin: *");
				print json_encode($response);
				
			}else if($_POST['app'] == 'localizeScript' || $_GET['app'] == 'localizeScript'){
				
				session_start();
				header("Content-type: application/json; charset=utf-8");
				$response = $this->appLogin();
				if(isset($response['status']) && $response['status'] == 'error'){
					
					print json_encode($response);
					die();
					
				}
				
				$url = site_url();
				#$url = admin_url();
				$nonce = wp_create_nonce('get_json_for_web_app');
				$nonceUrl = wp_nonce_url($url, 'get_json_for_web_app', 'app_nonce' );
				#$nonceUrl .= '&_wp_http_referer='.esc_attr(wp_unslash($_SERVER['REQUEST_URI']));
				$response = array('user' => $response);
				$dictionary = array();
				$localizeScriptList = array('adomin', 'schedule_page', 'setting_page');
				for($i = 0; $i < count($localizeScriptList); $i++){
					
					$response[$localizeScriptList[$i]] = $this->localizeScript($localizeScriptList[$i]);
					$response[$localizeScriptList[$i]]['url'] = $nonceUrl;
					$dictionary = array_merge($dictionary, $this->getDictionary($localizeScriptList[$i], $this->plugin_name));
					
				}
				
				$response['dictionary'] = $dictionary;
				$response['wp_get_current_user'] = wp_get_current_user();
				$response['wp_get_session_token'] = wp_get_session_token();
				$response['session_id'] = session_id();
				$response['referer_field'] = esc_attr(wp_unslash($_SERVER['REQUEST_URI']));
				$response['nonce'] = $nonce;
				$response['wp_get_session_token'] = wp_get_session_token();
				$response['wp_nonce_tick'] = wp_nonce_tick();
				print json_encode($response);
				
			}else if($_POST['app'] == 'json' || $_GET['app'] == 'json'){
				
				$_SERVER['REQUEST_URI'] = '/';
				#session_start();
				#wp_set_current_user(0, '');
				$verify_nonce = wp_verify_nonce($_GET['app_nonce'], 'get_json_for_web_app', false);
				#$verify_nonce = check_ajax_referer($this->action_control."_ajax", $_POST['nonce'], false);
				if (isset($_GET['app_nonce']) && ($verify_nonce)){
					
					$response = $this->choeseMode();
					/**
					$response['verify_nonce'] = $verify_nonce;
					$response['wp_get_current_user'] = wp_get_current_user();
					$response['wp_get_session_token'] = wp_get_session_token();
					$response['wp_get_referer'] = wp_get_referer();
					$response['session_id'] = session_id();
					**/
					print json_encode($response);
					
				}else{
					
					#print wp_verify_nonce( $_GET['app_nonce'], 'get_json_for_web_app');
					$response['verify_nonce'] = $verify_nonce;
					$response['wp_get_current_user'] = wp_get_current_user();
					$response['wp_get_session_token'] = wp_get_session_token();
					$response['wp_get_referer'] = wp_get_referer();
					#$response['session_id'] = session_id();
					print json_encode($response);
					#print wp_referer_field(true);
					
				}
				
			}
			
			die();
			
		}
		
		public function appLogin(){
			
			$creds = array('user_login' => sanitize_text_field($_POST['user']), 'user_password' => sanitize_text_field($_POST['password']), 'remember' => true);
			if(isset($_GET['app'])){
				
				$creds = array('user_login' => sanitize_text_field($_GET['user']), 'user_password' => sanitize_text_field($_GET['password']), 'remember' => true);
				
			}
			
			$p_v = $this->plugin_version;
			$response = array();
			$user = wp_signon($creds, false);
			if(is_wp_error($user)){
				
				$response = array('status' => 'error', 'user' => $user, 'app_version' => $p_v);
				
			}else{
				
				$response = array('status' => 'error');
				$id = $user->data->ID;
				$user_nicename = $user->data->user_nicename;
				$allcaps = $user->allcaps;
				if(isset($allcaps['level_3']) && $allcaps['level_3'] === true){
					
					$response = array('status' => 'success', 'id' => $id, 'user_nicename' => $user_nicename, 'app_version' => $p_v);
					
				}
				
			}
			
			return $response;
			
		}
		
		public function cron_interval(){
			
			$time = 60 * 5;
			$schedules['retry_to_send_to_server'] = array(
        		'interval' => $time,
				'display'  => 'retry_to_send_to_server',
			);
 
    		return $schedules;
			
		}
		
		public function retry_to_send_to_server(){
			
			$name = $this->prefix."retry_to_send_to_server";
			$count = intval(get_option($name, 0));
			$count++;
			if($count == 1){
				
				add_option($name, $count);
				
			}else{
				
				update_option($name, $count);
				
			}
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
            
            $schedule = new Schedule($this->prefix, $this->plugin_name);
            $schedule->retryToSendToServer();
			
		}
		
		public function deactivation_event(){
			
			$timestamp = wp_next_scheduled(array($this, 'retry_to_send_to_server'));
			wp_unschedule_event($timestamp, array($this, 'retry_to_send_to_server'));
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			$setting = new setting($this->prefix, $this->plugin_name);
			$setting->activation(BOOKING_PACKAGE_EXTENSION_URL, "deactivation");
			
		}
		
		public function screen_meta($id){
			
			/**
			$screen = get_current_screen();
        	$screen->add_help_tab(array(
				'id'    => 'shortCode',
				'title'   => 'Get Shortcode', 
				'content' => '<p>Use filter for date to reduce output results for appointments. You can filter by <b>location</b>, <b>service</b>, <b>worker</b>, <b>status</b> and <b>date</b>.</p>'
			));
			
			$screen->set_help_sidebar('<a href="https://easy-appointments.net/documentation/">More info!</a>');
			**/
			
		}
		
		public function createFirstCalendar(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$schedule->createFirstCalendar();
			
		}
		
		public function getFontFaceStyle(){
			
			$url = plugin_dir_url( __FILE__ );
			
			$style = "<style>\n";
			$style .= "	@font-face {\n";
			$style .= "		font-family: 'Material Icons';\n";
			$style .= "		font-style: normal;\n";
			$style .= "		font-weight: 400;\n";
			$style .= "		src: url(".$url."iconfont/MaterialIcons-Regular.eot);\n";
			$style .= "		src: local('Material Icons'),\n";
			$style .= "			local('MaterialIcons-Regular'),\n";
			$style .= "			url(".$url."iconfont/MaterialIcons-Regular.woff2) format('woff2'),\n";
			$style .= "			url(".$url."iconfont/MaterialIcons-Regular.woff) format('woff'),\n";
			$style .= "			url(".$url."iconfont/MaterialIcons-Regular.ttf) format('truetype');\n";
			$style .= "	}\n";
			$style .= "</style>\n";
			return $style;
			
		}
		
		public function getStyle($list){
			
			$style = '<style type="text/css">';
			$style .= "#bookingPackage { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; font-size: ".$list['Design']['booking_package_fontSize']['value']."}\n";
			$style .= "#bookingPackage button { font-size: ".$list['Design']['booking_package_fontSize']['value']."}\n";
			$style .= "#durationStay { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#durationStay .bookingDetailsTitle { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#calendarPage { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#scheduleMainPanel { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#courseMainPanel { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#schedulePage { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#schedulePage .topPanel { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#schedulePage .bottomPanel { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#schedulePage .selectedDate { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#inputFormPanel { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#inputFormPanel .selectedDate { background-color: ".$list['Design']['booking_package_backgroundColor']['value']."; }\n";
			$style .= "#calendarPage .dayPanel { background-color: ".$list['Design']['booking_package_calendarBackgroundColorWithSchedule']['value']."; }\n";
			$style .= "#calendarPage .closeDay { background-color: ".$list['Design']['booking_package_calendarBackgroundColorWithNoSchedule']['value']."; }\n";
			$style .= "#schedulePage .selectPanel { background-color: ".$list['Design']['booking_package_scheduleAndServiceBackgroundColor']['value']."; }\n";
			$style .= "#schedulePage .selectPanelError { background-color: ".$list['Design']['booking_package_scheduleAndServiceBackgroundColor']['value']."; }\n";
			$style .= "#schedulePage .selectPanelActive { background-color: ".$list['Design']['booking_package_backgroundColorOfSelectedLabel']['value']."; }\n";
			$style .= "#schedulePage .selectPanel:hover { background-color: ".$list['Design']['booking_package_mouseHover']['value']."; }\n";
			$style .= "#calendarPage .pointer:hover { background-color: ".$list['Design']['booking_package_mouseHover']['value']."; }\n";
			
			$styleList = array(
				"#calendarPage .dayPanel", 
				"#schedulePage .selectPanel", 
				"#schedulePage .selectPanelError", 
				"#schedulePage .daysListPanel", 
				"#schedulePage .topPanel", 
				"#schedulePage .bottomPanel",
				"#inputFormPanel .selectedDate",
				"#inputFormPanel .row",
				"#durationStay .row",
				"#durationStay .bookingDetailsTitle",
			);
			for($i = 0; $i < count($styleList); $i++){
				
				$style .= $styleList[$i]." { border-color: ".$list['Design']['booking_package_borderColor']['value']."; }\n";
				
			}
			
			$style .= "</style>";
			
			return $style;
			
		}
		
		public function getDictionary($mode, $pluginName){
			
			$dictionary = array(
				'Error' => __('Error', $pluginName),
				'Add' => __('Add', $pluginName),
				'Delete' => __('Delete', $pluginName),
				'Edit' => __('Edit', $pluginName),
				'Change' => __('Change', $pluginName),
				'Return' => __('Return', $pluginName),
				'Save' => __('Save', $pluginName),
				'Cancel' => __('Cancel', $pluginName),
				'Close' => __('Close', $pluginName),
				'Help' => __('Help', $pluginName),
				'Price' => __('Price', $pluginName),
				'Warning' => __('Warning', $pluginName),
				'Booking' => __('Booking', $pluginName),
				'January' => __('January', $pluginName),
				'February' => __('February', $pluginName),
				'March' => __('March', $pluginName),
				'April' => __('April', $pluginName),
				'May' => __('May', $pluginName),
				'June' => __('June', $pluginName),
				'July' => __('July', $pluginName),
				'August' => __('August', $pluginName),
				'September' => __('September', $pluginName),
				'October' => __('October', $pluginName),
				'November' => __('November', $pluginName),
				'December' => __('December', $pluginName),
				'Jan' => __('Jan', $pluginName),
				'Feb' => __('Feb', $pluginName),
				'Mar' => __('Mar', $pluginName),
				'Apr' => __('Apr', $pluginName),
				'May' => __('May', $pluginName),
				'Jun' => __('Jun', $pluginName),
				'Jul' => __('Jul', $pluginName),
				'Aug' => __('Aug', $pluginName),
				'Sep' => __('Sep', $pluginName),
				'Oct' => __('Oct', $pluginName),
				'Nov' => __('Nov', $pluginName),
				'Dec' => __('Dec', $pluginName),
				'Sunday' => __('Sunday', $pluginName),
				'Monday' => __('Monday', $pluginName),
				'Tuesday' => __('Tuesday', $pluginName),
				'Wednesday' => __('Wednesday', $pluginName),
				'Thursday' => __('Thursday', $pluginName),
				'Friday' => __('Friday', $pluginName),
				'Saturday' => __('Saturday', $pluginName),
				'Sun' => __('Sun', $pluginName),
				'Mon' => __('Mon', $pluginName),
				'Tue' => __('Tue', $pluginName),
				'Wed' => __('Wed', $pluginName),
				'Thu' => __('Thu', $pluginName),
				'Fri' => __('Fri', $pluginName),
				'Sat' => __('Sat', $pluginName),
				'Booking Date' => __('Booking Date', $pluginName),
				'Arrival (Check-in)' => __('Arrival (Check-in)', $pluginName),
				'Departure (Check-out)' => __('Departure (Check-out)', $pluginName),
				'Arrival' => __('Arrival', $pluginName),
				'Departure' => __('Departure', $pluginName),
				'Check-in' => __('Check-in', $pluginName),
				'Check-out' => __('Check-out', $pluginName),
				'Total number of guests' => __('Total number of guests', $pluginName),
				'Total length of stay' => __('Total length of stay', $pluginName),
				'Additional fees' => __('Additional fees', $pluginName),
				'Accommodation fees' => __('Accommodation fees', $pluginName),
				'Total price' => __('Total price', $pluginName),
				'Summary' => __('Summary', $pluginName),
				'night' => __('night', $pluginName),
				'nights' => __('nights', $pluginName),
				'Title' => __('Title', $pluginName),
				/**
				'(for %s night)' => __('(for %s night)', $pluginName),
				'(for %s nights)' => __('(for %s nights)', $pluginName),
				**/
				'Clear' => __('Clear', $pluginName),
				'person' => __('person', $pluginName),
				'people' => __('people', $pluginName),
				'Please choose %s' => __('Please choose %s', $pluginName),
				'Please tap here and choose %s' => __('Please tap here and choose %s', $pluginName),
				'An error was found in JavaScript syntax. Send javascript syntax error to the author?' => __('An error was found in JavaScript syntax. Send javascript syntax error to the author?', $pluginName),
				'Subscription version' => __('Subscription version', $pluginName),
				'%s remaining' => __('%s remaining', $pluginName),
			);
			
			
			if($mode == "adomin"){
				
				$dictionary['Download CSV'] = __("Download CSV", $pluginName);
				$dictionary['No reservations'] = __("No reservations", $pluginName);
				$dictionary['No schedules'] = __('No schedules', $pluginName);
				$dictionary['APPROVED'] = __("APPROVED", $pluginName);
				$dictionary['PENDING'] = __('PENDING', $pluginName);
				$dictionary['No visitors'] = __('No visitors', $pluginName);
				
				$dictionary['Confirm send email'] = __('Confirm send email', $pluginName);
				$dictionary['Send email notification to customer and admin about this operation?'] = __('Send email notification to customer and admin about this operation?', $pluginName);
				$dictionary['Confirm contents update'] = __('Confirm contents update', $pluginName);
				$dictionary['Update to pending state about this operation?'] = __('Update to pending status about this operation?', $pluginName);
				$dictionary['Update to approval state about this operation?'] = __('Update to approval state about this operation?', $pluginName);
				$dictionary['Refund confirmation'] = __('Refund confirmation', $pluginName);
				$dictionary['This booking has been paid by credit card. Do you refund the price to the customer?'] = __('This booking has been paid by credit card. Do you refund the price to the customer?', $pluginName);
				$dictionary['Send email notification to customer and admin about this operation?'] = __('Send email notification to customer and admin about this operation?', $pluginName);
				$dictionary['Confirm deletion of data'] = __('Confirm deletion of data', $pluginName);
				$dictionary['Do you delete the booking about this operation?'] = __('Do you delete the booking about this operation?', $pluginName);
				$dictionary['Please upgrade your free plan to enable this feature.'] = __('Please upgrade your free plan to enable this feature.', $pluginName);
				$dictionary['Service is not registered. '] = __('Service is not registered. ', $pluginName);
				$dictionary['Please create a service on the setting page.'] = __('Please create a service on the setting page.', $pluginName);
				$dictionary['There is no room to booking'] = __('There is no room to booking', $pluginName);
				
			}else if($mode == "schedule_page"){
				
				$dictionary['Schedule setting'] = __('Schedule setting', $pluginName);
				$dictionary['Schedule setting on %s'] = __('Schedule setting on %s', $pluginName);
				$dictionary['hour'] = __('hour', $pluginName);
				$dictionary['minutes'] = __('minutes', $pluginName);
				$dictionary['Choose %s'] = __('Choose %s', $pluginName);
				$dictionary['Select booking business'] = __('Select booking business', $pluginName);
				$dictionary['Calendar status'] = __('Calendar status', $pluginName);
				$dictionary['Enable the service function'] = __('Enable the service function', $pluginName);
				$dictionary['Plan name'] = __('Plan name', $pluginName);
				$dictionary['Day (Be completed within your business hours)'] = __('Day (Be completed within your business hours)', $pluginName);
				$dictionary['Accommodation (Hotel)'] = __('Accommodation (Hotel)', $pluginName);
				$dictionary['Publish calendar'] = __('Publish calendar', $pluginName);
				$dictionary['Unpublish calendar'] = __('Unpublish calendar', $pluginName);
				$dictionary['An unknown cause of error occurred'] = __('An unknown cause of error occurred', $pluginName);
				$dictionary['Do you delete the "%s" about this operation?'] = __('Do you delete the "%s" about this operation?', $pluginName);
				$dictionary['Edit schedule'] = __('Edit schedule', $pluginName);
				$dictionary['Return to Calendar list'] = __('Return to Calendar list', $pluginName);
				$dictionary['Add new calendar'] = __('Add new calendar', $pluginName);
				$dictionary['Status'] = __('Status', $pluginName);
				$dictionary['Short Code'] = __('Short Code', $pluginName);
				$dictionary['Name'] = __('Name', $pluginName);
				$dictionary['Active'] = __('Active', $pluginName);
				$dictionary['Price'] = __('Price', $pluginName);
				$dictionary['Duration time'] = __('Duration time', $pluginName);
				$dictionary['Unique ID'] = __('Unique ID', $pluginName);
				$dictionary['Value'] = __('Value', $pluginName);
				$dictionary['Required'] = __('Required', $pluginName);
				$dictionary['Is Name'] = __('Is Name', $pluginName);
				$dictionary['Is a location in Google Calendar'] = __('Is a location in Google Calendar', $pluginName);
				$dictionary['Is Email'] = __('Is Email', $pluginName);
				$dictionary['Type'] = __('Type', $pluginName);
				$dictionary['Options'] = __('Options', $pluginName);
				$dictionary['Add service'] = __('Add service', $pluginName);
				$dictionary['Change ranking'] = __('Change ranking', $pluginName);
				$dictionary['Add filed'] = __('Add filed', $pluginName);
				$dictionary['Do you delete service of "%s"?'] = __('Do you delete service of "%s"?', $pluginName);
				$dictionary['Do you delete filed of "%s"?'] = __('Do you delete filed of "%s"?', $pluginName);
				$dictionary['Disable'] = __('Disable', $pluginName);
				$dictionary['Enable'] = __('Enable', $pluginName);
				$dictionary['New booking'] = __('New booking', $pluginName);
				$dictionary['New booking(Visitor)'] = __('New booking(Visitor)', $pluginName);
				$dictionary['Approval of booking'] = __('Approval of booking', $pluginName);
				$dictionary['Pending of booking'] = __('Pending of booking', $pluginName);
				$dictionary['Cancellation of booking'] = __('Cancellation of booking', $pluginName);
				$dictionary['Delete of booking'] = __('Delete of booking', $pluginName);
				$dictionary['Subject'] = __('Subject', $pluginName);
				$dictionary['Content'] = __('Content', $pluginName);
				$dictionary['Google Calendar ID'] = __('Google Calendar ID', $pluginName);
				$dictionary['State'] = __('State', $pluginName);
				$dictionary['Date'] = __('Date', $pluginName);
				$dictionary['Number of rooms available'] = __('Number of rooms available', $pluginName);
				$dictionary['Cost per night'] = __('Cost per night', $pluginName);
				$dictionary['Maximum number of people staying in one room'] = __('Maximum number of people staying in one room', $pluginName);
				$dictionary['Include children in the maximum number of people in the room'] = __('Include children in the maximum number of people in the room', $pluginName);
				$dictionary['Expressions of arrival and departure'] = __('Expressions of arrival and departure', $pluginName);
				$dictionary['Exclude'] = __('Exclude', $pluginName);
				$dictionary['Include'] = __('Include', $pluginName);
				$dictionary['Confirm deletion of calendar'] = __('Confirm deletion of calendar', $pluginName);
				$dictionary['Number of people'] = __('Number of people', $pluginName);
				$dictionary['Booking is completed within 24 hours (hair salon, hospital etc.)'] = __('Booking is completed within 24 hours (hair salon, hospital etc.)', $pluginName);
				$dictionary['Accommodation (hotels, campgrounds, etc.)'] = __('Accommodation (hotels, campgrounds, etc.)', $pluginName);
				$dictionary['You can use following shortcodes in content editer.'] = __('You can use following shortcodes in content editer.', $pluginName);
				$dictionary['[%s] is inserting "%s"'] = __('[%s] is inserting "%s"', $pluginName);
				$dictionary['Fixed calendar'] = __('Fixed calendar', $pluginName);
				
			}else if($mode == "setting_page"){
				
				$dictionary['Cancel subscription'] = __('Cancel subscription', $pluginName);
				$dictionary['You can use following shortcodes in content editer.'] = __('You can use following shortcodes in content editer.', $pluginName);
				$dictionary['Add filed'] = __('Add filed', $pluginName);
				$dictionary['Change ranking'] = __('Change ranking', $pluginName);
				$dictionary['Add service'] = __('Add service', $pluginName);
				$dictionary['New Course'] = __('New Course', $pluginName);
				$dictionary['New service'] = __('New service', $pluginName);
				$dictionary['Refresh token'] = __('Refresh token', $pluginName);
				$dictionary['Name'] = __('Name', $pluginName);
				$dictionary['Active'] = __('Active', $pluginName);
				$dictionary['Price'] = __('Price', $pluginName);
				$dictionary['Duration time'] = __('Duration time', $pluginName);
				$dictionary['Unique ID'] = __('Unique ID', $pluginName);
				$dictionary['Value'] = __('Value', $pluginName);
				$dictionary['Required'] = __('Required', $pluginName);
				$dictionary['Is Name'] = __('Is Name', $pluginName);
				$dictionary['Is a location in Google Calendar'] = __('Is a location in Google Calendar', $pluginName);
				$dictionary['Is Email'] = __('Is Email', $pluginName);
				$dictionary['Type'] = __('Type', $pluginName);
				$dictionary['Options'] = __('Options', $pluginName);
				#$dictionary['New booking(Admin)'] = __('New booking(Admin)', $pluginName);
				$dictionary['Email is sending to Admin after Making of booking.'] = __('Email is sending to Admin after Making of booking.', $pluginName);
				#$dictionary['New booking(Visitor)'] = __('New booking(Visitor)', $pluginName);
				$dictionary['Email is sending to visitor after Making of booking.'] = __('Email is sending to visitor after Making of booking.', $pluginName);
				#$dictionary['Approval of booking'] = __('Approval of booking', $pluginName);
				#$dictionary['Pending of booking'] = __('Pending of booking', $pluginName);
				$dictionary['Booking status is set to Pending'] = __('Booking status is set to Pending', $pluginName);
				$dictionary['Email is sending to Visitor after Booking set as Pending.'] = __('Email is sending to Visitor after Booking set as Pending.', $pluginName);
				$dictionary['Cancellation of booking'] = __('Cancellation of booking', $pluginName);
				$dictionary['Email is sending to Visitor after Deletion of booking.'] = __('Email is sending to Visitor after Deletion of booking.', $pluginName);
				$dictionary['Please upgrade your free plan to enable this feature.'] = __('Please upgrade your free plan to enable this feature.', $pluginName);
				$dictionary['The Service account must be in JSON format.'] = __('The Service account must be in JSON format.', $pluginName);
				
				$dictionary['Subscriptions ID'] = __('Subscriptions ID', $pluginName);
				$dictionary['Invoice ID'] = __('Invoice ID', $pluginName);
				$dictionary['Expiration date'] = __('Expiration date', $pluginName);
				$dictionary['Customers email'] = __('Customers email', $pluginName);
				$dictionary['By using iCal you can share calendars and reservations for Google Calendar, Apple Calendar, iCal format.'] = __('By using iCal you can share calendars and reservations for Google Calendar, Apple Calendar, iCal format.', $pluginName);
				#$dictionary['By using the Google Calendar API you can share information on reserved users with Google Calendar. And you can make and edit new booking from Google Calendar.'] = __('By using the Google Calendar API you can share information on reserved users with Google Calendar. And you can make and edit new booking from Google Calendar.', $pluginName);
				$dictionary['Mailgun is an email automation service. It offers a complete cloud-based email service for sending, receiving and tracking email sent through your websites and applications.'] = __('Mailgun is an email automation service. It offers a complete cloud-based email service for sending, receiving and tracking email sent through your websites and applications.', $pluginName);
				$dictionary['Stripe is the best way to accept payments online and in mobile apps.'] = __('Stripe is the best way to accept payments online and in mobile apps.', $pluginName);
				$dictionary['Do you delete option of "%s"?'] = __('Do you delete option of "%s"?', $pluginName);
				$dictionary['Do you really cancel the subscription?'] = __('Do you really cancel the subscription?', $pluginName);
				$dictionary['Do you delete service of "%s"?'] = __('Do you delete service of "%s"?', $pluginName);
				$dictionary['Do you delete filed of "%s"?'] = __('Do you delete filed of "%s"?', $pluginName);
				$dictionary['General'] = __('General', $pluginName);
				$dictionary['Country'] = __('Country', $pluginName);
				$dictionary['Selected country'] = __('Selected country', $pluginName);
				$dictionary['Frequently used countries'] = __('Frequently used countries', $pluginName);
				$dictionary['Other countries'] = __('Other countries', $pluginName);
				$dictionary['Subject'] = __('Subject', $pluginName);
				$dictionary['Content'] = __('Content', $pluginName);
				
			}else if($mode == "Upgrade_js"){
				
				$dictionary['Credit card'] = __('Credit card', $pluginName);
				$dictionary['Submit Payment'] = __('Submit Payment', $pluginName);
				$dictionary['You have to input missing text fields.'] = __('You have to input missing text fields.', $pluginName);
				$dictionary['Please choose a plan.'] = __('Please choose a plan.', $pluginName);
				$dictionary['First Name'] = __('First Name', $pluginName);
				$dictionary['Last Name'] = __('Last Name', $pluginName);
				$dictionary['Email address'] = __('Email address', $pluginName);
				$dictionary['By taking out a subscription, you agree to %s.'] = __('By taking out a subscription, you agree to %s.', $pluginName);
				$dictionary['the terms of Service'] = __('the terms of Service', $pluginName);
				$dictionary['Thank you for signing up for the subscription.'] = __('Thank you for signing up for the subscription.', $pluginName);
				$dictionary['Please reload this browser.'] = __('Please reload this browser.', $pluginName);
				$dictionary['To subscribe to the paid version of Booking Package you must use HTTPS.'] = __('To subscribe to the paid version of Booking Package you must use HTTPS.', $pluginName);
				
			}else if($mode == "bookingPageForVisitors"){
				
				$dictionary['Please fill in your details'] = __('Please fill in your details', $pluginName);
				$dictionary['Reservation details'] = __('Reservation details', $pluginName);
				$dictionary['Booking details'] = __('Booking details', $pluginName);
				$dictionary['Your Booking Details'] = __('Your Booking Details', $pluginName);
				$dictionary['Booking now'] = __('Booking now', $pluginName);
				$dictionary['Return to schedules'] = __('Return to schedules', $pluginName);
				$dictionary['Return to calendar'] = __('Return to calendar', $pluginName);
				$dictionary['Reservation Completed'] = __('Reservation Completed', $pluginName);
				$dictionary['Booking Completed'] = __('Booking Completed', $pluginName);
				$dictionary['Credit card'] = __('Credit card', $pluginName);
				$dictionary['Payment & Booking'] = __('Payment & Booking', $pluginName);
				$dictionary['Booking & Payment now'] = __('Booking & Payment now', $pluginName);
				$dictionary['Service is not registered. '] = __('Service is not registered. ', $pluginName);
				$dictionary['Please create a service on the setting page.'] = __('Please create a service on the setting page.', $pluginName);
				
				
			}
			
			return $dictionary;
			
		}
		
		
	}	
	
	$booking_package = new Booking_app();
	
	
?>